Class: Google::Apis::AlloydbV1::BackupDrInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Information about BackupDR protection for this cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupDrInfo

Returns a new instance of BackupDrInfo.



421
422
423
# File 'lib/google/apis/alloydb_v1/classes.rb', line 421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_windowGoogle::Apis::AlloydbV1::BackupDrEnabledWindow

Information about a single window when BackupDR was enabled for this cluster. Corresponds to the JSON property currentWindow



410
411
412
# File 'lib/google/apis/alloydb_v1/classes.rb', line 410

def current_window
  @current_window
end

#previous_windowsArray<Google::Apis::AlloydbV1::BackupDrEnabledWindow>

Windows during which BackupDR was enabled for this cluster, along with associated configuration for that window. These are used to determine points- in-time for which restores can be performed. The windows are ordered with the most recent window last. Windows are mutally exclusive. Windows which closed more than 1 year ago will be removed from this list. Corresponds to the JSON property previousWindows



419
420
421
# File 'lib/google/apis/alloydb_v1/classes.rb', line 419

def previous_windows
  @previous_windows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



426
427
428
429
# File 'lib/google/apis/alloydb_v1/classes.rb', line 426

def update!(**args)
  @current_window = args[:current_window] if args.key?(:current_window)
  @previous_windows = args[:previous_windows] if args.key?(:previous_windows)
end