Class: Google::Apis::AlloydbV1::DataplexConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::DataplexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Configuration for Dataplex integration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Dataplex is enabled by default for resources such as clusters and instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataplexConfig
constructor
A new instance of DataplexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataplexConfig
Returns a new instance of DataplexConfig.
1248 1249 1250 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Dataplex is enabled by default for resources such as clusters and instances.
This flag controls the integration of AlloyDB PG resources (like databases,
schemas, and tables) with Dataplex."
Corresponds to the JSON property enabled
1245 1246 1247 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1245 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1253 1254 1255 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1253 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |