Class: Google::Apis::AlloydbV1::EncryptionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

EncryptionInfo describes the encryption information of a cluster or a backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionInfo

Returns a new instance of EncryptionInfo.



1324
1325
1326
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_typeString

Output only. Type of encryption. Corresponds to the JSON property encryptionType

Returns:

  • (String)


1316
1317
1318
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1316

def encryption_type
  @encryption_type
end

#kms_key_versionsArray<String>

Output only. Cloud KMS key versions that are being used to protect the database or the backup. Corresponds to the JSON property kmsKeyVersions

Returns:

  • (Array<String>)


1322
1323
1324
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1322

def kms_key_versions
  @kms_key_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1329
1330
1331
1332
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1329

def update!(**args)
  @encryption_type = args[:encryption_type] if args.key?(:encryption_type)
  @kms_key_versions = args[:kms_key_versions] if args.key?(:kms_key_versions)
end