Class: Google::Apis::AlloydbV1::IntegerRestrictions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Restrictions on INTEGER type values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegerRestrictions

Returns a new instance of IntegerRestrictions.



2110
2111
2112
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_valueFixnum

The maximum value that can be specified, if applicable. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


2103
2104
2105
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2103

def max_value
  @max_value
end

#min_valueFixnum

The minimum value that can be specified, if applicable. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


2108
2109
2110
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2108

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2115
2116
2117
2118
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2115

def update!(**args)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end