Class: Google::Apis::AlloydbV1::ListClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::ListClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message for response to listing Clusters
Instance Attribute Summary collapse
-
#clusters ⇒ Array<Google::Apis::AlloydbV1::Cluster>
The list of Cluster Corresponds to the JSON property
clusters. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClustersResponse
constructor
A new instance of ListClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClustersResponse
Returns a new instance of ListClustersResponse.
2136 2137 2138 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2136 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Array<Google::Apis::AlloydbV1::Cluster>
The list of Cluster
Corresponds to the JSON property clusters
2124 2125 2126 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2124 def clusters @clusters end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2129 2130 2131 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2129 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2134 2135 2136 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2134 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2141 2142 2143 2144 2145 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2141 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |