Class: Google::Apis::AlloydbV1::ListInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::ListInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message for response to listing Instances
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::AlloydbV1::Instance>
The list of Instance Corresponds to the JSON property
instances. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstancesResponse
constructor
A new instance of ListInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstancesResponse
Returns a new instance of ListInstancesResponse.
2167 2168 2169 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::AlloydbV1::Instance>
The list of Instance
Corresponds to the JSON property instances
2155 2156 2157 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2155 def instances @instances end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2160 2161 2162 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2160 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2165 2166 2167 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2165 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2172 2173 2174 2175 2176 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2172 def update!(**args) @instances = args[:instances] if args.key?(:instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |