Class: Google::Apis::AlloydbV1::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message for response to listing Users
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
-
#users ⇒ Array<Google::Apis::AlloydbV1::User>
The list of User Corresponds to the JSON property
users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
2251 2252 2253 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2239 2240 2241 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2239 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2244 2245 2246 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2244 def unreachable @unreachable end |
#users ⇒ Array<Google::Apis::AlloydbV1::User>
The list of User
Corresponds to the JSON property users
2249 2250 2251 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2249 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2256 2257 2258 2259 2260 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2256 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @users = args[:users] if args.key?(:users) end |