Class: Google::Apis::AlloydbV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



2674
2675
2676
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2633
2634
2635
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2633

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2638
2639
2640
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2638

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2643
2644
2645
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2643

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2651
2652
2653
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2651

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2657
2658
2659
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2657

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2662
2663
2664
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2662

def target
  @target
end

#upgrade_cluster_statusGoogle::Apis::AlloydbV1::UpgradeClusterStatus

Message for current status of the Major Version Upgrade operation. Corresponds to the JSON property upgradeClusterStatus



2667
2668
2669
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2667

def upgrade_cluster_status
  @upgrade_cluster_status
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2672
2673
2674
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2672

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2679

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @upgrade_cluster_status = args[:upgrade_cluster_status] if args.key?(:upgrade_cluster_status)
  @verb = args[:verb] if args.key?(:verb)
end