Class: Google::Apis::AlloydbV1::PromoteClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::PromoteClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message for promoting a Cluster
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PromoteClusterRequest
constructor
A new instance of PromoteClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PromoteClusterRequest
Returns a new instance of PromoteClusterRequest.
2781 2782 2783 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. The current etag of the Cluster. If an etag is provided and does not
match the current etag of the Cluster, deletion will be blocked and an ABORTED
error will be returned.
Corresponds to the JSON property etag
2757 2758 2759 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2757 def etag @etag end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if original
operation with the same request ID was received, and if so, will ignore the
second request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
2771 2772 2773 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2771 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
2778 2779 2780 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2778 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2786 2787 2788 2789 2790 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2786 def update!(**args) @etag = args[:etag] if args.key?(:etag) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |