Class: Google::Apis::AlloydbV1::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

PscConfig contains PSC related configuration at a cluster level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



2872
2873
2874
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#psc_enabledBoolean Also known as: psc_enabled?

Optional. Create an instance that allows connections from Private Service Connect endpoints to the instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


2863
2864
2865
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2863

def psc_enabled
  @psc_enabled
end

#service_owned_project_numberFixnum

Output only. The project number that needs to be allowlisted on the network attachment to enable outbound connectivity. Corresponds to the JSON property serviceOwnedProjectNumber

Returns:

  • (Fixnum)


2870
2871
2872
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2870

def service_owned_project_number
  @service_owned_project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2877
2878
2879
2880
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2877

def update!(**args)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @service_owned_project_number = args[:service_owned_project_number] if args.key?(:service_owned_project_number)
end