Class: Google::Apis::AlloydbV1::PscInterfaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Configuration for setting up a PSC interface to enable outbound connectivity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscInterfaceConfig

Returns a new instance of PscInterfaceConfig.



2904
2905
2906
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_attachment_resourceString

The network attachment resource created in the consumer network to which the PSC interface will be linked. This is of the format: "projects/$ CONSUMER_PROJECT/regions/$REGION/networkAttachments/$ NETWORK_ATTACHMENT_NAME". The network attachment must be in the same region as the instance. Corresponds to the JSON property networkAttachmentResource

Returns:

  • (String)


2902
2903
2904
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2902

def network_attachment_resource
  @network_attachment_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2909
2910
2911
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2909

def update!(**args)
  @network_attachment_resource = args[:network_attachment_resource] if args.key?(:network_attachment_resource)
end