Class: Google::Apis::AlloydbV1::QueryInsightsInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::QueryInsightsInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
QueryInsights Instance specific configuration.
Instance Attribute Summary collapse
-
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all queries combined.
-
#query_string_length ⇒ Fixnum
Query string length.
-
#record_application_tags ⇒ Boolean
(also: #record_application_tags?)
Record application tags for an instance.
-
#record_client_address ⇒ Boolean
(also: #record_client_address?)
Record client address for an instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryInsightsInstanceConfig
constructor
A new instance of QueryInsightsInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryInsightsInstanceConfig
Returns a new instance of QueryInsightsInstanceConfig.
3004 3005 3006 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all
queries combined. The default value is 5. Any integer between 0 and 20 is
considered valid.
Corresponds to the JSON property queryPlansPerMinute
2983 2984 2985 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2983 def query_plans_per_minute @query_plans_per_minute end |
#query_string_length ⇒ Fixnum
Query string length. The default value is 1024. Any integer between 256 and
4500 is considered valid.
Corresponds to the JSON property queryStringLength
2989 2990 2991 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2989 def query_string_length @query_string_length end |
#record_application_tags ⇒ Boolean Also known as:
Record application tags for an instance. This flag is turned "on" by default.
Corresponds to the JSON property recordApplicationTags
2994 2995 2996 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2994 def @record_application_tags end |
#record_client_address ⇒ Boolean Also known as: record_client_address?
Record client address for an instance. Client address is PII information. This
flag is turned "on" by default.
Corresponds to the JSON property recordClientAddress
3001 3002 3003 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3001 def record_client_address @record_client_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3009 3010 3011 3012 3013 3014 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3009 def update!(**args) @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute) @query_string_length = args[:query_string_length] if args.key?(:query_string_length) @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags) @record_client_address = args[:record_client_address] if args.key?(:record_client_address) end |