Class: Google::Apis::AlloydbV1::RestartInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::RestartInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Instance Attribute Summary collapse
-
#node_ids ⇒ Array<String>
Optional.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestartInstanceRequest
constructor
A new instance of RestartInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestartInstanceRequest
Returns a new instance of RestartInstanceRequest.
3123 3124 3125 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#node_ids ⇒ Array<String>
Optional. Full name of the nodes as obtained from INSTANCE_VIEW_FULL to
restart upon. Applicable only to read instances.
Corresponds to the JSON property nodeIds
3099 3100 3101 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3099 def node_ids @node_ids end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3113 3114 3115 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3113 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
3120 3121 3122 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3120 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3128 3129 3130 3131 3132 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3128 def update!(**args) @node_ids = args[:node_ids] if args.key?(:node_ids) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |