Class: Google::Apis::AlloydbV1::RestoreFromCloudSqlRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Message for registering Restoring from CloudSQL resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreFromCloudSqlRequest

Returns a new instance of RestoreFromCloudSqlRequest.



3231
3232
3233
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloudsql_backup_run_sourceGoogle::Apis::AlloydbV1::CloudSqlBackupRunSource

The source CloudSQL backup resource. Corresponds to the JSON property cloudsqlBackupRunSource



3217
3218
3219
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3217

def cloudsql_backup_run_source
  @cloudsql_backup_run_source
end

#clusterGoogle::Apis::AlloydbV1::Cluster

A cluster is a collection of regional AlloyDB resources. It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed. Corresponds to the JSON property cluster



3224
3225
3226
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3224

def cluster
  @cluster
end

#cluster_idString

Required. ID of the requesting object. Corresponds to the JSON property clusterId

Returns:

  • (String)


3229
3230
3231
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3229

def cluster_id
  @cluster_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3236
3237
3238
3239
3240
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3236

def update!(**args)
  @cloudsql_backup_run_source = args[:cloudsql_backup_run_source] if args.key?(:cloudsql_backup_run_source)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
end