Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.



3595
3596
3597
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



3567
3568
3569
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3567

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



3572
3573
3574
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3572

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



3578
3579
3580
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3578

def backupdr_configuration
  @backupdr_configuration
end

#full_resource_nameString

Required. Full resource name of this instance. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


3583
3584
3585
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3583

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time backup configuration was refreshed. Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


3588
3589
3590
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3588

def last_refresh_time
  @last_refresh_time
end

#resource_idGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



3593
3594
3595
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3593

def resource_id
  @resource_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3600
3601
3602
3603
3604
3605
3606
3607
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3600

def update!(**args)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
end