Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Common model for database resource health signal data.
Instance Attribute Summary collapse
-
#additional_metadata ⇒ Hash<String,Object>
Any other additional metadata Corresponds to the JSON property
additionalMetadata. -
#compliance ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainCompliance>
Industry standards associated with this signal; if this signal is an issue, that could be a violation of the associated industry standard(s).
-
#description ⇒ String
Description associated with signal Corresponds to the JSON property
description. -
#event_time ⇒ String
Required.
-
#external_uri ⇒ String
The external-uri of the signal, using which more information about this signal can be obtained.
-
#location ⇒ String
This is used to identify the location of the resource.
-
#name ⇒ String
Required.
-
#provider ⇒ String
Cloud provider name.
-
#resource_container ⇒ String
Closest parent container of this resource.
-
#resource_name ⇒ String
Required.
-
#signal_class ⇒ String
Required.
-
#signal_id ⇒ String
Required.
-
#signal_severity ⇒ String
The severity of the signal, such as if it's a HIGH or LOW severity.
-
#signal_type ⇒ String
Required.
-
#state ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData
Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData.
3936 3937 3938 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_metadata ⇒ Hash<String,Object>
Any other additional metadata
Corresponds to the JSON property additionalMetadata
3850 3851 3852 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3850 def @additional_metadata end |
#compliance ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainCompliance>
Industry standards associated with this signal; if this signal is an issue,
that could be a violation of the associated industry standard(s). For example,
AUTO_BACKUP_DISABLED signal is associated with CIS GCP 1.1, CIS GCP 1.2, CIS
GCP 1.3, NIST 800-53 and ISO-27001 compliance standards. If a database
resource does not have automated backup enable, it will violate these
following industry standards.
Corresponds to the JSON property compliance
3860 3861 3862 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3860 def compliance @compliance end |
#description ⇒ String
Description associated with signal
Corresponds to the JSON property description
3865 3866 3867 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3865 def description @description end |
#event_time ⇒ String
Required. The last time at which the event described by this signal took place
Corresponds to the JSON property eventTime
3870 3871 3872 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3870 def event_time @event_time end |
#external_uri ⇒ String
The external-uri of the signal, using which more information about this signal
can be obtained. In GCP, this will take user to SCC page to get more details
about signals.
Corresponds to the JSON property externalUri
3877 3878 3879 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3877 def external_uri @external_uri end |
#location ⇒ String
This is used to identify the location of the resource. Example: "us-central1"
Corresponds to the JSON property location
3882 3883 3884 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3882 def location @location end |
#name ⇒ String
Required. The name of the signal, ex: PUBLIC_SQL_INSTANCE,
SQL_LOG_ERROR_VERBOSITY etc.
Corresponds to the JSON property name
3888 3889 3890 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3888 def name @name end |
#provider ⇒ String
Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged
Corresponds to the JSON property provider
3893 3894 3895 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3893 def provider @provider end |
#resource_container ⇒ String
Closest parent container of this resource. In GCP, 'container' refers to a
Cloud Resource Manager project. It must be resource name of a Cloud Resource
Manager project with the format of "provider//", such as "projects/123". For
GCP provided resources, number should be project number.
Corresponds to the JSON property resourceContainer
3901 3902 3903 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3901 def resource_container @resource_container end |
#resource_name ⇒ String
Required. Database resource name associated with the signal. Resource name to
follow CAIS resource_name format as noted here go/condor-common-datamodel
Corresponds to the JSON property resourceName
3907 3908 3909 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3907 def resource_name @resource_name end |
#signal_class ⇒ String
Required. The class of the signal, such as if it's a THREAT or VULNERABILITY.
Corresponds to the JSON property signalClass
3912 3913 3914 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3912 def signal_class @signal_class end |
#signal_id ⇒ String
Required. Unique identifier for the signal. This is an unique id which would
be mainatined by partner to identify a signal.
Corresponds to the JSON property signalId
3918 3919 3920 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3918 def signal_id @signal_id end |
#signal_severity ⇒ String
The severity of the signal, such as if it's a HIGH or LOW severity.
Corresponds to the JSON property signalSeverity
3923 3924 3925 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3923 def signal_severity @signal_severity end |
#signal_type ⇒ String
Required. Type of signal, for example, AVAILABLE_IN_MULTIPLE_ZONES,
LOGGING_MOST_ERRORS, etc.
Corresponds to the JSON property signalType
3929 3930 3931 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3929 def signal_type @signal_type end |
#state ⇒ String
Required. The state of the signal, such as if it's ACTIVE or RESOLVED.
Corresponds to the JSON property state
3934 3935 3936 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3934 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3941 3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 3957 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3941 def update!(**args) @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata) @compliance = args[:compliance] if args.key?(:compliance) @description = args[:description] if args.key?(:description) @event_time = args[:event_time] if args.key?(:event_time) @external_uri = args[:external_uri] if args.key?(:external_uri) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @resource_container = args[:resource_container] if args.key?(:resource_container) @resource_name = args[:resource_name] if args.key?(:resource_name) @signal_class = args[:signal_class] if args.key?(:signal_class) @signal_id = args[:signal_id] if args.key?(:signal_id) @signal_severity = args[:signal_severity] if args.key?(:signal_severity) @signal_type = args[:signal_type] if args.key?(:signal_type) @state = args[:state] if args.key?(:state) end |