Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData.



4329
4330
4331
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_runGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4285
4286
4287
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4285

def backup_run
  @backup_run
end

#full_resource_nameString

Required. Full Resource name of the source resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


4290
4291
4292
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4290

def full_resource_name
  @full_resource_name
end

#last_refresh_timeString

Required. Last time signal was refreshed Corresponds to the JSON property lastRefreshTime

Returns:

  • (String)


4295
4296
4297
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4295

def last_refresh_time
  @last_refresh_time
end

#locationString

Required. Resource location. Corresponds to the JSON property location

Returns:

  • (String)


4300
4301
4302
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4300

def location
  @location
end

#resource_idGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



4305
4306
4307
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4305

def resource_id
  @resource_id
end

#signal_bool_valueBoolean Also known as: signal_bool_value?

Deprecated: Use signal_metadata_list instead. Corresponds to the JSON property signalBoolValue

Returns:

  • (Boolean)


4310
4311
4312
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4310

def signal_bool_value
  @signal_bool_value
end

#signal_metadata_listArray<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainSignalMetadata>

This will support array of OneOf signal metadata information for a given signal type. Corresponds to the JSON property signalMetadataList



4317
4318
4319
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4317

def 
  @signal_metadata_list
end

#signal_stateString

Required. Output only. Signal state of the signal Corresponds to the JSON property signalState

Returns:

  • (String)


4322
4323
4324
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4322

def signal_state
  @signal_state
end

#signal_typeString

Required. Signal type of the signal Corresponds to the JSON property signalType

Returns:

  • (String)


4327
4328
4329
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4327

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4334
4335
4336
4337
4338
4339
4340
4341
4342
4343
4344
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4334

def update!(**args)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time)
  @location = args[:location] if args.key?(:location)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value)
  @signal_metadata_list = args[:signal_metadata_list] if args.key?(:signal_metadata_list)
  @signal_state = args[:signal_state] if args.key?(:signal_state)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end