Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainIpAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Used to send IP address information for a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainIpAddress

Returns a new instance of StorageDatabasecenterPartnerapiV1mainIpAddress.



4481
4482
4483
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_ipString

The private IP address assigned to the resource within a Virtual Private Cloud (VPC). This IP is only reachable from within the same VPC network. Stored in standard string format (e.g., "10.0.0.2"). Corresponds to the JSON property privateIp

Returns:

  • (String)


4473
4474
4475
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4473

def private_ip
  @private_ip
end

#public_ipString

The public IP address assigned to the resource. This IP is reachable from the internet. Stored in standard string format (e.g., "34.72.1.1"). Corresponds to the JSON property publicIp

Returns:

  • (String)


4479
4480
4481
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4479

def public_ip
  @public_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4486
4487
4488
4489
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4486

def update!(**args)
  @private_ip = args[:private_ip] if args.key?(:private_ip)
  @public_ip = args[:public_ip] if args.key?(:public_ip)
end