Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Disable validation warnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule

Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule.



4619
4620
4621
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateGoogle::Apis::AlloydbV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endDate



4598
4599
4600
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4598

def end_date
  @end_date
end

#start_dateGoogle::Apis::AlloydbV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property startDate



4610
4611
4612
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4610

def start_date
  @start_date
end

#timeGoogle::Apis::AlloydbV1::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property time



4617
4618
4619
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4617

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4624
4625
4626
4627
4628
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4624

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
  @time = args[:time] if args.key?(:time)
end