Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Disable validation warnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo.



4683
4684
4685
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_version_release_dateGoogle::Apis::AlloydbV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property currentVersionReleaseDate



4645
4646
4647
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4645

def current_version_release_date
  @current_version_release_date
end

#deny_maintenance_schedulesArray<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule>

Optional. Disable validation warnings Corresponds to the JSON property denyMaintenanceSchedules



4650
4651
4652
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4650

def deny_maintenance_schedules
  @deny_maintenance_schedules
end

#is_instance_stoppedBoolean Also known as: is_instance_stopped?

Optional. Disable validation warnings Corresponds to the JSON property isInstanceStopped

Returns:

  • (Boolean)


4655
4656
4657
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4655

def is_instance_stopped
  @is_instance_stopped
end

#maintenance_scheduleGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule

Disable validation warnings Corresponds to the JSON property maintenanceSchedule



4661
4662
4663
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4661

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_stateString

Output only. Disable validation warnings Corresponds to the JSON property maintenanceState

Returns:

  • (String)


4666
4667
4668
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4666

def maintenance_state
  @maintenance_state
end

#maintenance_versionString

Optional. Disable validation warnings Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


4671
4672
4673
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4671

def maintenance_version
  @maintenance_version
end

#next_available_maintenance_versionsArray<String>

Optional. Disable validation warnings Corresponds to the JSON property nextAvailableMaintenanceVersions

Returns:

  • (Array<String>)


4676
4677
4678
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4676

def next_available_maintenance_versions
  @next_available_maintenance_versions
end

#upcoming_maintenanceGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainUpcomingMaintenance

Disable validation warnings Corresponds to the JSON property upcomingMaintenance



4681
4682
4683
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4681

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4688

def update!(**args)
  @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date)
  @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules)
  @is_instance_stopped = args[:is_instance_stopped] if args.key?(:is_instance_stopped)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_state = args[:maintenance_state] if args.key?(:maintenance_state)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @next_available_maintenance_versions = args[:next_available_maintenance_versions] if args.key?(:next_available_maintenance_versions)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end