Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainUserLabels

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainUserLabels

Returns a new instance of StorageDatabasecenterPartnerapiV1mainUserLabels.



4933
4934
4935
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4931
4932
4933
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4931

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4938
4939
4940
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4938

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end