Class: Google::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Product specification for Condor resources.
Instance Attribute Summary collapse
-
#engine ⇒ String
The specific engine that the underlying database is running.
-
#minor_version ⇒ String
Minor version of the underlying database engine.
-
#type ⇒ String
Type of specific database product.
-
#version ⇒ String
Version of the underlying database engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterProtoCommonProduct
constructor
A new instance of StorageDatabasecenterProtoCommonProduct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterProtoCommonProduct
Returns a new instance of StorageDatabasecenterProtoCommonProduct.
4970 4971 4972 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#engine ⇒ String
The specific engine that the underlying database is running.
Corresponds to the JSON property engine
4950 4951 4952 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4950 def engine @engine end |
#minor_version ⇒ String
Minor version of the underlying database engine. Example values: For MySQL, it
could be "8.0.32", "5.7.32" etc.. For Postgres, it could be "14.3", "15.3" etc.
.
Corresponds to the JSON property minorVersion
4957 4958 4959 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4957 def minor_version @minor_version end |
#type ⇒ String
Type of specific database product. It could be CloudSQL, AlloyDB etc..
Corresponds to the JSON property type
4962 4963 4964 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4962 def type @type end |
#version ⇒ String
Version of the underlying database engine. Example values: For MySQL, it could
be "8.0", "5.7" etc.. For Postgres, it could be "14", "15" etc..
Corresponds to the JSON property version
4968 4969 4970 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4968 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4975 4976 4977 4978 4979 4980 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4975 def update!(**args) @engine = args[:engine] if args.key?(:engine) @minor_version = args[:minor_version] if args.key?(:minor_version) @type = args[:type] if args.key?(:type) @version = args[:version] if args.key?(:version) end |