Class: Google::Apis::AlloydbV1::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Message describing User object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



5394
5395
5396
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_rolesArray<String>

Optional. List of database roles this user has. The database role strings are subject to the PostgreSQL naming conventions. Corresponds to the JSON property databaseRoles

Returns:

  • (Array<String>)


5369
5370
5371
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5369

def database_roles
  @database_roles
end

#keep_extra_rolesBoolean Also known as: keep_extra_roles?

Input only. If the user already exists and it has additional roles, keep them granted. Corresponds to the JSON property keepExtraRoles

Returns:

  • (Boolean)


5375
5376
5377
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5375

def keep_extra_roles
  @keep_extra_roles
end

#nameString

Output only. Name of the resource in the form of projects/project/locations/ location/cluster/cluster/users/user. Corresponds to the JSON property name

Returns:

  • (String)


5382
5383
5384
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5382

def name
  @name
end

#passwordString

Input only. Password for the user. Corresponds to the JSON property password

Returns:

  • (String)


5387
5388
5389
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5387

def password
  @password
end

#user_typeString

Optional. Type of this user. Corresponds to the JSON property userType

Returns:

  • (String)


5392
5393
5394
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5392

def user_type
  @user_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5399
5400
5401
5402
5403
5404
5405
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5399

def update!(**args)
  @database_roles = args[:database_roles] if args.key?(:database_roles)
  @keep_extra_roles = args[:keep_extra_roles] if args.key?(:keep_extra_roles)
  @name = args[:name] if args.key?(:name)
  @password = args[:password] if args.key?(:password)
  @user_type = args[:user_type] if args.key?(:user_type)
end