Class: Google::Apis::AlloydbV1::AlloydbClhErrorsAlloyDbInternalDebugInfo
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::AlloydbClhErrorsAlloyDbInternalDebugInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
AlloyDbInternalDebugInfo contains internal debugging information for AlloyDB errors. It is explicitly kept out of the allowlist (errors.yaml) to ensure it is sanitized (stripped) by OnePlatform for all external requests. Used only to carry internal error details to across UPC/FlowLib boundary for ObservabilityInfo.
Instance Attribute Summary collapse
-
#original_error ⇒ String
Corresponds to the JSON property
originalError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlloydbClhErrorsAlloyDbInternalDebugInfo
constructor
A new instance of AlloydbClhErrorsAlloyDbInternalDebugInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlloydbClhErrorsAlloyDbInternalDebugInfo
Returns a new instance of AlloydbClhErrorsAlloyDbInternalDebugInfo.
38 39 40 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 38 def initialize(**args) update!(**args) end |
Instance Attribute Details
#original_error ⇒ String
Corresponds to the JSON property originalError
36 37 38 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 36 def original_error @original_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43 44 45 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 43 def update!(**args) @original_error = args[:original_error] if args.key?(:original_error) end |