Class: Google::Apis::AlloydbV1::BackupSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Message describing a BackupSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupSource

Returns a new instance of BackupSource.



475
476
477
# File 'lib/google/apis/alloydb_v1/classes.rb', line 475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_nameString

Required. The name of the backup resource with the format: * projects/project /locations/region/backups/backup_id Corresponds to the JSON property backupName

Returns:

  • (String)


466
467
468
# File 'lib/google/apis/alloydb_v1/classes.rb', line 466

def backup_name
  @backup_name
end

#backup_uidString

Output only. The system-generated UID of the backup which was used to create this resource. The UID is generated when the backup is created, and it is retained until the backup is deleted. Corresponds to the JSON property backupUid

Returns:

  • (String)


473
474
475
# File 'lib/google/apis/alloydb_v1/classes.rb', line 473

def backup_uid
  @backup_uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



480
481
482
483
# File 'lib/google/apis/alloydb_v1/classes.rb', line 480

def update!(**args)
  @backup_name = args[:backup_name] if args.key?(:backup_name)
  @backup_uid = args[:backup_uid] if args.key?(:backup_uid)
end