Class: Google::Apis::AlloydbV1::ClusterUpgradeDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Upgrade details of a cluster. This cluster can be primary or secondary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeDetails

Returns a new instance of ClusterUpgradeDetails.



924
925
926
# File 'lib/google/apis/alloydb_v1/classes.rb', line 924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_typeString

Cluster type which can either be primary or secondary. Corresponds to the JSON property clusterType

Returns:

  • (String)


895
896
897
# File 'lib/google/apis/alloydb_v1/classes.rb', line 895

def cluster_type
  @cluster_type
end

#database_versionString

Database version of the cluster after the upgrade operation. This will be the target version if the upgrade was successful otherwise it remains the same as that before the upgrade operation. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


902
903
904
# File 'lib/google/apis/alloydb_v1/classes.rb', line 902

def database_version
  @database_version
end

#instance_upgrade_detailsArray<Google::Apis::AlloydbV1::InstanceUpgradeDetails>

Upgrade details of the instances directly associated with this cluster. Corresponds to the JSON property instanceUpgradeDetails



907
908
909
# File 'lib/google/apis/alloydb_v1/classes.rb', line 907

def instance_upgrade_details
  @instance_upgrade_details
end

#nameString

Normalized name of the cluster Corresponds to the JSON property name

Returns:

  • (String)


912
913
914
# File 'lib/google/apis/alloydb_v1/classes.rb', line 912

def name
  @name
end

#stage_infoArray<Google::Apis::AlloydbV1::StageInfo>

Array containing stage info associated with this cluster. Corresponds to the JSON property stageInfo



917
918
919
# File 'lib/google/apis/alloydb_v1/classes.rb', line 917

def stage_info
  @stage_info
end

#upgrade_statusString

Upgrade status of the cluster. Corresponds to the JSON property upgradeStatus

Returns:

  • (String)


922
923
924
# File 'lib/google/apis/alloydb_v1/classes.rb', line 922

def upgrade_status
  @upgrade_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



929
930
931
932
933
934
935
936
# File 'lib/google/apis/alloydb_v1/classes.rb', line 929

def update!(**args)
  @cluster_type = args[:cluster_type] if args.key?(:cluster_type)
  @database_version = args[:database_version] if args.key?(:database_version)
  @instance_upgrade_details = args[:instance_upgrade_details] if args.key?(:instance_upgrade_details)
  @name = args[:name] if args.key?(:name)
  @stage_info = args[:stage_info] if args.key?(:stage_info)
  @upgrade_status = args[:upgrade_status] if args.key?(:upgrade_status)
end