Class: Google::Apis::AlloydbV1::ClusterUpgradeDetails
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::ClusterUpgradeDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Upgrade details of a cluster. This cluster can be primary or secondary.
Instance Attribute Summary collapse
-
#cluster_type ⇒ String
Cluster type which can either be primary or secondary.
-
#database_version ⇒ String
Database version of the cluster after the upgrade operation.
-
#instance_upgrade_details ⇒ Array<Google::Apis::AlloydbV1::InstanceUpgradeDetails>
Upgrade details of the instances directly associated with this cluster.
-
#name ⇒ String
Normalized name of the cluster Corresponds to the JSON property
name. -
#stage_info ⇒ Array<Google::Apis::AlloydbV1::StageInfo>
Array containing stage info associated with this cluster.
-
#upgrade_status ⇒ String
Upgrade status of the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterUpgradeDetails
constructor
A new instance of ClusterUpgradeDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterUpgradeDetails
Returns a new instance of ClusterUpgradeDetails.
901 902 903 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_type ⇒ String
Cluster type which can either be primary or secondary.
Corresponds to the JSON property clusterType
872 873 874 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 872 def cluster_type @cluster_type end |
#database_version ⇒ String
Database version of the cluster after the upgrade operation. This will be the
target version if the upgrade was successful otherwise it remains the same as
that before the upgrade operation.
Corresponds to the JSON property databaseVersion
879 880 881 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 879 def database_version @database_version end |
#instance_upgrade_details ⇒ Array<Google::Apis::AlloydbV1::InstanceUpgradeDetails>
Upgrade details of the instances directly associated with this cluster.
Corresponds to the JSON property instanceUpgradeDetails
884 885 886 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 884 def instance_upgrade_details @instance_upgrade_details end |
#name ⇒ String
Normalized name of the cluster
Corresponds to the JSON property name
889 890 891 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 889 def name @name end |
#stage_info ⇒ Array<Google::Apis::AlloydbV1::StageInfo>
Array containing stage info associated with this cluster.
Corresponds to the JSON property stageInfo
894 895 896 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 894 def stage_info @stage_info end |
#upgrade_status ⇒ String
Upgrade status of the cluster.
Corresponds to the JSON property upgradeStatus
899 900 901 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 899 def upgrade_status @upgrade_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
906 907 908 909 910 911 912 913 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 906 def update!(**args) @cluster_type = args[:cluster_type] if args.key?(:cluster_type) @database_version = args[:database_version] if args.key?(:database_version) @instance_upgrade_details = args[:instance_upgrade_details] if args.key?(:instance_upgrade_details) @name = args[:name] if args.key?(:name) @stage_info = args[:stage_info] if args.key?(:stage_info) @upgrade_status = args[:upgrade_status] if args.key?(:upgrade_status) end |