Class: Google::Apis::AlloydbV1::ContinuousBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::ContinuousBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
ContinuousBackupConfig describes the continuous backups recovery configurations of a cluster.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether ContinuousBackup is enabled.
-
#encryption_config ⇒ Google::Apis::AlloydbV1::EncryptionConfig
EncryptionConfig describes the encryption config of a cluster or a backup that is encrypted with a CMEK (customer-managed encryption key).
-
#recovery_window_days ⇒ Fixnum
The number of days that are eligible to restore from using PITR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContinuousBackupConfig
constructor
A new instance of ContinuousBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContinuousBackupConfig
Returns a new instance of ContinuousBackupConfig.
1033 1034 1035 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether ContinuousBackup is enabled.
Corresponds to the JSON property enabled
1017 1018 1019 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1017 def enabled @enabled end |
#encryption_config ⇒ Google::Apis::AlloydbV1::EncryptionConfig
EncryptionConfig describes the encryption config of a cluster or a backup that
is encrypted with a CMEK (customer-managed encryption key).
Corresponds to the JSON property encryptionConfig
1024 1025 1026 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1024 def encryption_config @encryption_config end |
#recovery_window_days ⇒ Fixnum
The number of days that are eligible to restore from using PITR. To support
the entire recovery window, backups and logs are retained for one day more
than the recovery window. If not set, defaults to 14 days.
Corresponds to the JSON property recoveryWindowDays
1031 1032 1033 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1031 def recovery_window_days @recovery_window_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1038 1039 1040 1041 1042 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1038 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @recovery_window_days = args[:recovery_window_days] if args.key?(:recovery_window_days) end |