Class: Google::Apis::AlloydbV1::CsvImportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Options for importing data in CSV format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CsvImportOptions

Returns a new instance of CsvImportOptions.



1180
1181
1182
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<String>

Optional. The columns to which CSV data is imported. If not specified, all columns of the database table are loaded with CSV data. Corresponds to the JSON property columns

Returns:

  • (Array<String>)


1152
1153
1154
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1152

def columns
  @columns
end

#escape_characterString

Optional. Specifies the character that should appear before a data character that needs to be escaped. The default is same as quote character. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property escapeCharacter

Returns:

  • (String)


1159
1160
1161
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1159

def escape_character
  @escape_character
end

#field_delimiterString

Optional. Specifies the character that separates columns within each row (line) of the file. The default is comma. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property fieldDelimiter

Returns:

  • (String)


1166
1167
1168
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1166

def field_delimiter
  @field_delimiter
end

#quote_characterString

Optional. Specifies the quoting character to be used when a data value is quoted. The default is double-quote. The value of this argument has to be a character in Hex ASCII Code. Corresponds to the JSON property quoteCharacter

Returns:

  • (String)


1173
1174
1175
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1173

def quote_character
  @quote_character
end

#tableString

Required. The database table to import CSV file into. Corresponds to the JSON property table

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1178

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1185
1186
1187
1188
1189
1190
1191
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1185

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @escape_character = args[:escape_character] if args.key?(:escape_character)
  @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter)
  @quote_character = args[:quote_character] if args.key?(:quote_character)
  @table = args[:table] if args.key?(:table)
end