Class: Google::Apis::AlloydbV1::DataplexConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::DataplexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Configuration for Dataplex integration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Dataplex is enabled by default for resources such as clusters and instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataplexConfig
constructor
A new instance of DataplexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataplexConfig
Returns a new instance of DataplexConfig.
1224 1225 1226 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Dataplex is enabled by default for resources such as clusters and instances.
This flag controls the integration of AlloyDB PG resources (like databases,
schemas, and tables) with Dataplex."
Corresponds to the JSON property enabled
1221 1222 1223 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1221 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1229 1230 1231 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1229 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |