Class: Google::Apis::AlloydbV1::DataplexConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::DataplexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Configuration for Dataplex integration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Dataplex is enabled by default for resources such as clusters and instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataplexConfig
constructor
A new instance of DataplexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataplexConfig
Returns a new instance of DataplexConfig.
1206 1207 1208 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Dataplex is enabled by default for resources such as clusters and instances.
This flag controls the integration of AlloyDB PG resources (like databases,
schemas, and tables) with Dataplex."
Corresponds to the JSON property enabled
1203 1204 1205 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1203 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1211 1212 1213 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1211 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |