Class: Google::Apis::AlloydbV1::ExportClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Export cluster request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportClusterRequest

Returns a new instance of ExportClusterRequest.



1355
1356
1357
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_export_optionsGoogle::Apis::AlloydbV1::CsvExportOptions

Options for exporting data in CSV format. Corresponds to the JSON property csvExportOptions



1336
1337
1338
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1336

def csv_export_options
  @csv_export_options
end

#databaseString

Required. Name of the database where the export command will be executed. Note

  • Value provided should be the same as expected from SELECT current_database() ; and NOT as a resource reference. Corresponds to the JSON property database

Returns:

  • (String)


1343
1344
1345
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1343

def database
  @database
end

#gcs_destinationGoogle::Apis::AlloydbV1::GcsDestination

Destination for Export. Export will be done to cloud storage. Corresponds to the JSON property gcsDestination



1348
1349
1350
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1348

def gcs_destination
  @gcs_destination
end

#sql_export_optionsGoogle::Apis::AlloydbV1::SqlExportOptions

Options for exporting data in SQL format. Corresponds to the JSON property sqlExportOptions



1353
1354
1355
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1353

def sql_export_options
  @sql_export_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1360
1361
1362
1363
1364
1365
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1360

def update!(**args)
  @csv_export_options = args[:csv_export_options] if args.key?(:csv_export_options)
  @database = args[:database] if args.key?(:database)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @sql_export_options = args[:sql_export_options] if args.key?(:sql_export_options)
end