Class: Google::Apis::AlloydbV1::InjectFaultRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::InjectFaultRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message for triggering fault injection on an instance
Instance Attribute Summary collapse
-
#fault_type ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InjectFaultRequest
constructor
A new instance of InjectFaultRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InjectFaultRequest
Returns a new instance of InjectFaultRequest.
1707 1708 1709 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fault_type ⇒ String
Required. The type of fault to be injected in an instance.
Corresponds to the JSON property faultType
1683 1684 1685 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1683 def fault_type @fault_type end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
1697 1698 1699 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1697 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
1704 1705 1706 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1704 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1712 1713 1714 1715 1716 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1712 def update!(**args) @fault_type = args[:fault_type] if args.key?(:fault_type) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |