Class: Google::Apis::AlloydbV1::InjectFaultRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::InjectFaultRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message for triggering fault injection on an instance
Instance Attribute Summary collapse
-
#fault_type ⇒ String
Required.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InjectFaultRequest
constructor
A new instance of InjectFaultRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InjectFaultRequest
Returns a new instance of InjectFaultRequest.
1701 1702 1703 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fault_type ⇒ String
Required. The type of fault to be injected in an instance.
Corresponds to the JSON property faultType
1677 1678 1679 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1677 def fault_type @fault_type end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
1691 1692 1693 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1691 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
1698 1699 1700 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1698 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1706 1707 1708 1709 1710 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 1706 def update!(**args) @fault_type = args[:fault_type] if args.key?(:fault_type) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) end |