Class: Google::Apis::AlloydbV1::IntegerRestrictions
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::IntegerRestrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Restrictions on INTEGER type values.
Instance Attribute Summary collapse
-
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
-
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntegerRestrictions
constructor
A new instance of IntegerRestrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntegerRestrictions
Returns a new instance of IntegerRestrictions.
2069 2070 2071 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Fixnum
The maximum value that can be specified, if applicable.
Corresponds to the JSON property maxValue
2062 2063 2064 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2062 def max_value @max_value end |
#min_value ⇒ Fixnum
The minimum value that can be specified, if applicable.
Corresponds to the JSON property minValue
2067 2068 2069 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2067 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2074 2075 2076 2077 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2074 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |