Class: Google::Apis::AlloydbV1::MaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

MaintenanceWindow specifies a preferred day and time for maintenance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceWindow

Returns a new instance of MaintenanceWindow.



2371
2372
2373
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc. Corresponds to the JSON property day

Returns:

  • (String)


2362
2363
2364
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2362

def day
  @day
end

#start_timeGoogle::Apis::AlloydbV1::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



2369
2370
2371
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2369

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2376
2377
2378
2379
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2376

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @start_time = args[:start_time] if args.key?(:start_time)
end