Class: Google::Apis::AlloydbV1::Node

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Details of a single node in the instance. Nodes in an AlloyDB instance are ephemeral, they can change during update, failover, autohealing and resize operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Node

Returns a new instance of Node.



2485
2486
2487
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. The identifier of the VM e.g. "test-read-0601-407e52be-ms3l". Corresponds to the JSON property id

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2458

def id
  @id
end

#ipString

Output only. The private IP address of the VM e.g. "10.57.0.34". Corresponds to the JSON property ip

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2463

def ip
  @ip
end

#is_hot_standbyBoolean Also known as: is_hot_standby?

Output only. Indicates whether the node set up to be configured as a hot standby. Corresponds to the JSON property isHotStandby

Returns:

  • (Boolean)


2469
2470
2471
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2469

def is_hot_standby
  @is_hot_standby
end

#stateString

Output only. Determined by state of the compute VM and postgres-service health. Compute VM state can have values listed in https://cloud.google.com/compute/ docs/instances/instance-life-cycle and postgres-service health can have values: HEALTHY and UNHEALTHY. Corresponds to the JSON property state

Returns:

  • (String)


2478
2479
2480
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2478

def state
  @state
end

#zone_idString

Output only. The Compute Engine zone of the VM e.g. "us-central1-b". Corresponds to the JSON property zoneId

Returns:

  • (String)


2483
2484
2485
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2483

def zone_id
  @zone_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2490
2491
2492
2493
2494
2495
2496
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2490

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @ip = args[:ip] if args.key?(:ip)
  @is_hot_standby = args[:is_hot_standby] if args.key?(:is_hot_standby)
  @state = args[:state] if args.key?(:state)
  @zone_id = args[:zone_id] if args.key?(:zone_id)
end