Class: Google::Apis::AlloydbV1::Node
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::Node
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Details of a single node in the instance. Nodes in an AlloyDB instance are ephemeral, they can change during update, failover, autohealing and resize operations.
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#ip ⇒ String
Output only.
-
#is_hot_standby ⇒ Boolean
(also: #is_hot_standby?)
Output only.
-
#state ⇒ String
Output only.
-
#zone_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Node
constructor
A new instance of Node.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Node
Returns a new instance of Node.
2467 2468 2469 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. The identifier of the VM e.g. "test-read-0601-407e52be-ms3l".
Corresponds to the JSON property id
2440 2441 2442 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2440 def id @id end |
#ip ⇒ String
Output only. The private IP address of the VM e.g. "10.57.0.34".
Corresponds to the JSON property ip
2445 2446 2447 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2445 def ip @ip end |
#is_hot_standby ⇒ Boolean Also known as: is_hot_standby?
Output only. Indicates whether the node set up to be configured as a hot
standby.
Corresponds to the JSON property isHotStandby
2451 2452 2453 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2451 def is_hot_standby @is_hot_standby end |
#state ⇒ String
Output only. Determined by state of the compute VM and postgres-service health.
Compute VM state can have values listed in https://cloud.google.com/compute/
docs/instances/instance-life-cycle and postgres-service health can have values:
HEALTHY and UNHEALTHY.
Corresponds to the JSON property state
2460 2461 2462 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2460 def state @state end |
#zone_id ⇒ String
Output only. The Compute Engine zone of the VM e.g. "us-central1-b".
Corresponds to the JSON property zoneId
2465 2466 2467 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2465 def zone_id @zone_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2472 def update!(**args) @id = args[:id] if args.key?(:id) @ip = args[:ip] if args.key?(:ip) @is_hot_standby = args[:is_hot_standby] if args.key?(:is_hot_standby) @state = args[:state] if args.key?(:state) @zone_id = args[:zone_id] if args.key?(:zone_id) end |