Class: Google::Apis::AlloydbV1::ObservabilityInstanceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Observability Instance specific configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ObservabilityInstanceConfig

Returns a new instance of ObservabilityInstanceConfig.



2582
2583
2584
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Observability feature status for an instance. This flag is turned "off" by default. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2530
2531
2532
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2530

def enabled
  @enabled
end

#max_query_string_lengthFixnum

Query string length. The default value is 10k. Corresponds to the JSON property maxQueryStringLength

Returns:

  • (Fixnum)


2536
2537
2538
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2536

def max_query_string_length
  @max_query_string_length
end

#preserve_commentsBoolean Also known as: preserve_comments?

Preserve comments in query string for an instance. This flag is turned "off" by default. Corresponds to the JSON property preserveComments

Returns:

  • (Boolean)


2542
2543
2544
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2542

def preserve_comments
  @preserve_comments
end

#query_plans_per_minuteFixnum

Number of query execution plans captured by Insights per minute for all queries combined. The default value is 200. Any integer between 0 to 200 is considered valid. Corresponds to the JSON property queryPlansPerMinute

Returns:

  • (Fixnum)


2550
2551
2552
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2550

def query_plans_per_minute
  @query_plans_per_minute
end

#record_application_tagsBoolean Also known as: record_application_tags?

Record application tags for an instance. This flag is turned "off" by default. Corresponds to the JSON property recordApplicationTags

Returns:

  • (Boolean)


2555
2556
2557
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2555

def record_application_tags
  @record_application_tags
end

#track_active_queriesBoolean Also known as: track_active_queries?

Track actively running queries on the instance. If not set, this flag is "off" by default. Corresponds to the JSON property trackActiveQueries

Returns:

  • (Boolean)


2562
2563
2564
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2562

def track_active_queries
  @track_active_queries
end

#track_wait_event_typesBoolean Also known as: track_wait_event_types?

Output only. Track wait event types during query execution for an instance. This flag is turned "on" by default but tracking is enabled only after observability enabled flag is also turned on. This is read-only flag and only modifiable by internal API. Corresponds to the JSON property trackWaitEventTypes

Returns:

  • (Boolean)


2571
2572
2573
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2571

def track_wait_event_types
  @track_wait_event_types
end

#track_wait_eventsBoolean Also known as: track_wait_events?

Track wait events during query execution for an instance. This flag is turned " on" by default but tracking is enabled only after observability enabled flag is also turned on. Corresponds to the JSON property trackWaitEvents

Returns:

  • (Boolean)


2579
2580
2581
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2579

def track_wait_events
  @track_wait_events
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2587

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @max_query_string_length = args[:max_query_string_length] if args.key?(:max_query_string_length)
  @preserve_comments = args[:preserve_comments] if args.key?(:preserve_comments)
  @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute)
  @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags)
  @track_active_queries = args[:track_active_queries] if args.key?(:track_active_queries)
  @track_wait_event_types = args[:track_wait_event_types] if args.key?(:track_wait_event_types)
  @track_wait_events = args[:track_wait_events] if args.key?(:track_wait_events)
end