Class: Google::Apis::AlloydbV1::ObservabilityInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::ObservabilityInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Observability Instance specific configuration.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Observability feature status for an instance.
-
#max_query_string_length ⇒ Fixnum
Query string length.
-
#preserve_comments ⇒ Boolean
(also: #preserve_comments?)
Preserve comments in query string for an instance.
-
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all queries combined.
-
#record_application_tags ⇒ Boolean
(also: #record_application_tags?)
Record application tags for an instance.
-
#track_active_queries ⇒ Boolean
(also: #track_active_queries?)
Track actively running queries on the instance.
-
#track_wait_event_types ⇒ Boolean
(also: #track_wait_event_types?)
Output only.
-
#track_wait_events ⇒ Boolean
(also: #track_wait_events?)
Track wait events during query execution for an instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObservabilityInstanceConfig
constructor
A new instance of ObservabilityInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ObservabilityInstanceConfig
Returns a new instance of ObservabilityInstanceConfig.
2541 2542 2543 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2541 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Observability feature status for an instance. This flag is turned "off" by
default.
Corresponds to the JSON property enabled
2489 2490 2491 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2489 def enabled @enabled end |
#max_query_string_length ⇒ Fixnum
Query string length. The default value is 10k.
Corresponds to the JSON property maxQueryStringLength
2495 2496 2497 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2495 def max_query_string_length @max_query_string_length end |
#preserve_comments ⇒ Boolean Also known as: preserve_comments?
Preserve comments in query string for an instance. This flag is turned "off"
by default.
Corresponds to the JSON property preserveComments
2501 2502 2503 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2501 def preserve_comments @preserve_comments end |
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all
queries combined. The default value is 200. Any integer between 0 to 200 is
considered valid.
Corresponds to the JSON property queryPlansPerMinute
2509 2510 2511 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2509 def query_plans_per_minute @query_plans_per_minute end |
#record_application_tags ⇒ Boolean Also known as:
Record application tags for an instance. This flag is turned "off" by default.
Corresponds to the JSON property recordApplicationTags
2514 2515 2516 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2514 def @record_application_tags end |
#track_active_queries ⇒ Boolean Also known as: track_active_queries?
Track actively running queries on the instance. If not set, this flag is "off"
by default.
Corresponds to the JSON property trackActiveQueries
2521 2522 2523 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2521 def track_active_queries @track_active_queries end |
#track_wait_event_types ⇒ Boolean Also known as: track_wait_event_types?
Output only. Track wait event types during query execution for an instance.
This flag is turned "on" by default but tracking is enabled only after
observability enabled flag is also turned on. This is read-only flag and only
modifiable by internal API.
Corresponds to the JSON property trackWaitEventTypes
2530 2531 2532 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2530 def track_wait_event_types @track_wait_event_types end |
#track_wait_events ⇒ Boolean Also known as: track_wait_events?
Track wait events during query execution for an instance. This flag is turned "
on" by default but tracking is enabled only after observability enabled flag
is also turned on.
Corresponds to the JSON property trackWaitEvents
2538 2539 2540 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2538 def track_wait_events @track_wait_events end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2546 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @max_query_string_length = args[:max_query_string_length] if args.key?(:max_query_string_length) @preserve_comments = args[:preserve_comments] if args.key?(:preserve_comments) @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute) @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags) @track_active_queries = args[:track_active_queries] if args.key?(:track_active_queries) @track_wait_event_types = args[:track_wait_event_types] if args.key?(:track_wait_event_types) @track_wait_events = args[:track_wait_events] if args.key?(:track_wait_events) end |