Class: Google::Apis::AlloydbV1::PrimaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Configuration for the primary cluster. It has the list of clusters that are replicating from this cluster. This should be set if and only if the cluster is of type PRIMARY.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrimaryConfig

Returns a new instance of PrimaryConfig.



2696
2697
2698
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secondary_cluster_namesArray<String>

Output only. Names of the clusters that are replicating from this cluster. Corresponds to the JSON property secondaryClusterNames

Returns:

  • (Array<String>)


2694
2695
2696
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2694

def secondary_cluster_names
  @secondary_cluster_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2701
2702
2703
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2701

def update!(**args)
  @secondary_cluster_names = args[:secondary_cluster_names] if args.key?(:secondary_cluster_names)
end