Class: Google::Apis::AlloydbV1::PromoteClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Message for promoting a Cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PromoteClusterRequest

Returns a new instance of PromoteClusterRequest.



2739
2740
2741
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The current etag of the Cluster. If an etag is provided and does not match the current etag of the Cluster, deletion will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


2715
2716
2717
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2715

def etag
  @etag
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


2729
2730
2731
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2729

def request_id
  @request_id
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2736
2737
2738
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2736

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2744
2745
2746
2747
2748
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2744

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @request_id = args[:request_id] if args.key?(:request_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end