Class: Google::Apis::AlloydbV1::PscConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::PscConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
PscConfig contains PSC related configuration at a cluster level.
Instance Attribute Summary collapse
-
#psc_enabled ⇒ Boolean
(also: #psc_enabled?)
Optional.
-
#service_owned_project_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscConfig
constructor
A new instance of PscConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscConfig
Returns a new instance of PscConfig.
2831 2832 2833 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#psc_enabled ⇒ Boolean Also known as: psc_enabled?
Optional. Create an instance that allows connections from Private Service
Connect endpoints to the instance.
Corresponds to the JSON property pscEnabled
2822 2823 2824 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2822 def psc_enabled @psc_enabled end |
#service_owned_project_number ⇒ Fixnum
Output only. The project number that needs to be allowlisted on the network
attachment to enable outbound connectivity.
Corresponds to the JSON property serviceOwnedProjectNumber
2829 2830 2831 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2829 def service_owned_project_number @service_owned_project_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2836 2837 2838 2839 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2836 def update!(**args) @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled) @service_owned_project_number = args[:service_owned_project_number] if args.key?(:service_owned_project_number) end |