Class: Google::Apis::AlloydbV1::PscInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::PscInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
PscInstanceConfig contains PSC related configuration at an instance level.
Instance Attribute Summary collapse
-
#allowed_consumer_projects ⇒ Array<String>
Optional.
-
#psc_auto_connections ⇒ Array<Google::Apis::AlloydbV1::PscAutoConnectionConfig>
Optional.
-
#psc_dns_name ⇒ String
Output only.
-
#psc_interface_configs ⇒ Array<Google::Apis::AlloydbV1::PscInterfaceConfig>
Optional.
-
#service_attachment_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscInstanceConfig
constructor
A new instance of PscInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscInstanceConfig
Returns a new instance of PscInstanceConfig.
2877 2878 2879 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_consumer_projects ⇒ Array<String>
Optional. List of consumer projects that are allowed to create PSC endpoints
to service-attachments to this instance.
Corresponds to the JSON property allowedConsumerProjects
2850 2851 2852 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2850 def allowed_consumer_projects @allowed_consumer_projects end |
#psc_auto_connections ⇒ Array<Google::Apis::AlloydbV1::PscAutoConnectionConfig>
Optional. Configurations for setting up PSC service automation.
Corresponds to the JSON property pscAutoConnections
2855 2856 2857 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2855 def psc_auto_connections @psc_auto_connections end |
#psc_dns_name ⇒ String
Output only. The DNS name of the instance for PSC connectivity. Name
convention: ...alloydb-psc.goog
Corresponds to the JSON property pscDnsName
2861 2862 2863 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2861 def psc_dns_name @psc_dns_name end |
#psc_interface_configs ⇒ Array<Google::Apis::AlloydbV1::PscInterfaceConfig>
Optional. Configurations for setting up PSC interfaces attached to the
instance which are used for outbound connectivity. Only primary instances can
have PSC interface attached. Currently we only support 0 or 1 PSC interface.
Corresponds to the JSON property pscInterfaceConfigs
2868 2869 2870 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2868 def psc_interface_configs @psc_interface_configs end |
#service_attachment_link ⇒ String
Output only. The service attachment created when Private Service Connect (PSC)
is enabled for the instance. The name of the resource will be in the format of
projects//regions//serviceAttachments/
Corresponds to the JSON property serviceAttachmentLink
2875 2876 2877 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2875 def @service_attachment_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2882 2883 2884 2885 2886 2887 2888 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2882 def update!(**args) @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects) @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections) @psc_dns_name = args[:psc_dns_name] if args.key?(:psc_dns_name) @psc_interface_configs = args[:psc_interface_configs] if args.key?(:psc_interface_configs) @service_attachment_link = args[:service_attachment_link] if args.key?(:service_attachment_link) end |