Class: Google::Apis::AlloydbV1::QuantityBasedExpiry
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::QuantityBasedExpiry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
A backup's position in a quantity-based retention queue, of backups with the same source cluster and type, with length, retention, specified by the backup' s retention policy. Once the position is greater than the retention, the backup is eligible to be garbage collected. Example: 5 backups from the same source cluster and type with a quantity-based retention of 3 and denoted by backup_id (position, retention). Safe: backup_5 (1, 3), backup_4, (2, 3), backup_3 (3, 3). Awaiting garbage collection: backup_2 (4, 3), backup_1 (5, 3)
Instance Attribute Summary collapse
-
#retention_count ⇒ Fixnum
Output only.
-
#total_retention_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuantityBasedExpiry
constructor
A new instance of QuantityBasedExpiry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuantityBasedExpiry
Returns a new instance of QuantityBasedExpiry.
2955 2956 2957 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retention_count ⇒ Fixnum
Output only. The backup's position among its backups with the same source
cluster and type, by descending chronological order create time(i.e. newest
first).
Corresponds to the JSON property retentionCount
2947 2948 2949 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2947 def retention_count @retention_count end |
#total_retention_count ⇒ Fixnum
Output only. The length of the quantity-based queue, specified by the backup's
retention policy.
Corresponds to the JSON property totalRetentionCount
2953 2954 2955 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2953 def total_retention_count @total_retention_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2960 2961 2962 2963 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 2960 def update!(**args) @retention_count = args[:retention_count] if args.key?(:retention_count) @total_retention_count = args[:total_retention_count] if args.key?(:total_retention_count) end |