Class: Google::Apis::AlloydbV1::RestoreFromCloudSqlRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Message for registering Restoring from CloudSQL resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreFromCloudSqlRequest

Returns a new instance of RestoreFromCloudSqlRequest.



3190
3191
3192
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloudsql_backup_run_sourceGoogle::Apis::AlloydbV1::CloudSqlBackupRunSource

The source CloudSQL backup resource. Corresponds to the JSON property cloudsqlBackupRunSource



3176
3177
3178
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3176

def cloudsql_backup_run_source
  @cloudsql_backup_run_source
end

#clusterGoogle::Apis::AlloydbV1::Cluster

A cluster is a collection of regional AlloyDB resources. It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed. Corresponds to the JSON property cluster



3183
3184
3185
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3183

def cluster
  @cluster
end

#cluster_idString

Required. ID of the requesting object. Corresponds to the JSON property clusterId

Returns:

  • (String)


3188
3189
3190
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3188

def cluster_id
  @cluster_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3195
3196
3197
3198
3199
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3195

def update!(**args)
  @cloudsql_backup_run_source = args[:cloudsql_backup_run_source] if args.key?(:cloudsql_backup_run_source)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
end