Class: Google::Apis::AlloydbV1::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3410
3411
3412
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3393
3394
3395
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3393

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3398
3399
3400
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3398

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3403
3404
3405
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3403

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3408
3409
3410
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3408

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3415
3416
3417
3418
3419
3420
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3415

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end