Class: Google::Apis::AlloydbV1::Stats
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::Stats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Upgrade stats for read pool instances.
Instance Attribute Summary collapse
-
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
-
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
-
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
-
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stats
constructor
A new instance of Stats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stats
Returns a new instance of Stats.
3398 3399 3400 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
Corresponds to the JSON property failed
3381 3382 3383 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3381 def failed @failed end |
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
Corresponds to the JSON property notStarted
3386 3387 3388 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3386 def not_started @not_started end |
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
Corresponds to the JSON property ongoing
3391 3392 3393 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3391 def ongoing @ongoing end |
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Corresponds to the JSON property success
3396 3397 3398 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3396 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3403 3404 3405 3406 3407 3408 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3403 def update!(**args) @failed = args[:failed] if args.key?(:failed) @not_started = args[:not_started] if args.key?(:not_started) @ongoing = args[:ongoing] if args.key?(:ongoing) @success = args[:success] if args.key?(:success) end |