Class: Google::Apis::AlloydbV1::Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Upgrade stats for read pool instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stats

Returns a new instance of Stats.



3392
3393
3394
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFixnum

Number of read pool instances which failed to upgrade. Corresponds to the JSON property failed

Returns:

  • (Fixnum)


3375
3376
3377
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3375

def failed
  @failed
end

#not_startedFixnum

Number of read pool instances for which upgrade has not started. Corresponds to the JSON property notStarted

Returns:

  • (Fixnum)


3380
3381
3382
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3380

def not_started
  @not_started
end

#ongoingFixnum

Number of read pool instances undergoing upgrade. Corresponds to the JSON property ongoing

Returns:

  • (Fixnum)


3385
3386
3387
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3385

def ongoing
  @ongoing
end

#successFixnum

Number of read pool instances successfully upgraded. Corresponds to the JSON property success

Returns:

  • (Fixnum)


3390
3391
3392
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3390

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3397
3398
3399
3400
3401
3402
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3397

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @not_started = args[:not_started] if args.key?(:not_started)
  @ongoing = args[:ongoing] if args.key?(:ongoing)
  @success = args[:success] if args.key?(:success)
end