Class: Google::Apis::AlloydbV1::Stats
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::Stats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Upgrade stats for read pool instances.
Instance Attribute Summary collapse
-
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
-
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
-
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
-
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stats
constructor
A new instance of Stats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stats
Returns a new instance of Stats.
3392 3393 3394 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed ⇒ Fixnum
Number of read pool instances which failed to upgrade.
Corresponds to the JSON property failed
3375 3376 3377 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3375 def failed @failed end |
#not_started ⇒ Fixnum
Number of read pool instances for which upgrade has not started.
Corresponds to the JSON property notStarted
3380 3381 3382 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3380 def not_started @not_started end |
#ongoing ⇒ Fixnum
Number of read pool instances undergoing upgrade.
Corresponds to the JSON property ongoing
3385 3386 3387 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3385 def ongoing @ongoing end |
#success ⇒ Fixnum
Number of read pool instances successfully upgraded.
Corresponds to the JSON property success
3390 3391 3392 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3390 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3397 3398 3399 3400 3401 3402 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3397 def update!(**args) @failed = args[:failed] if args.key?(:failed) @not_started = args[:not_started] if args.key?(:not_started) @ongoing = args[:ongoing] if args.key?(:ongoing) @success = args[:success] if args.key?(:success) end |