Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Configuration for automatic backups

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupConfiguration.



3526
3527
3528
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_backup_enabledBoolean Also known as: automated_backup_enabled?

Whether customer visible automated backups are enabled on the instance. Corresponds to the JSON property automatedBackupEnabled

Returns:

  • (Boolean)


3510
3511
3512
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3510

def automated_backup_enabled
  @automated_backup_enabled
end

#backup_retention_settingsGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainRetentionSettings

Backup retention settings. Corresponds to the JSON property backupRetentionSettings



3516
3517
3518
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3516

def backup_retention_settings
  @backup_retention_settings
end

#point_in_time_recovery_enabledBoolean Also known as: point_in_time_recovery_enabled?

Whether point-in-time recovery is enabled. This is optional field, if the database service does not have this feature or metadata is not available in control plane, this can be omitted. Corresponds to the JSON property pointInTimeRecoveryEnabled

Returns:

  • (Boolean)


3523
3524
3525
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3523

def point_in_time_recovery_enabled
  @point_in_time_recovery_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3531
3532
3533
3534
3535
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3531

def update!(**args)
  @automated_backup_enabled = args[:automated_backup_enabled] if args.key?(:automated_backup_enabled)
  @backup_retention_settings = args[:backup_retention_settings] if args.key?(:backup_retention_settings)
  @point_in_time_recovery_enabled = args[:point_in_time_recovery_enabled] if args.key?(:point_in_time_recovery_enabled)
end