Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource.
Instance Attribute Summary collapse
-
#backup_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainBackupDrMetadata
Returns a new instance of StorageDatabasecenterPartnerapiV1mainBackupDrMetadata.
3589 3590 3591 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
3561 3562 3563 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3561 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
Corresponds to the JSON property backupRun
3566 3567 3568 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3566 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
3572 3573 3574 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3572 def backupdr_configuration @backupdr_configuration end |
#full_resource_name ⇒ String
Required. Full resource name of this instance.
Corresponds to the JSON property fullResourceName
3577 3578 3579 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3577 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time backup configuration was refreshed.
Corresponds to the JSON property lastRefreshTime
3582 3583 3584 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3582 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
3587 3588 3589 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3587 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3594 3595 3596 3597 3598 3599 3600 3601 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3594 def update!(**args) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) end |