Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#signal_bool_value ⇒ Boolean
(also: #signal_bool_value?)
Signal data for boolean signals.
-
#signal_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData
Returns a new instance of StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData.
3705 3706 3707 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
Required. Full Resource name of the source resource.
Corresponds to the JSON property fullResourceName
3682 3683 3684 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3682 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time signal was refreshed
Corresponds to the JSON property lastRefreshTime
3687 3688 3689 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3687 def last_refresh_time @last_refresh_time end |
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
3692 3693 3694 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3692 def resource_id @resource_id end |
#signal_bool_value ⇒ Boolean Also known as: signal_bool_value?
Signal data for boolean signals.
Corresponds to the JSON property signalBoolValue
3697 3698 3699 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3697 def signal_bool_value @signal_bool_value end |
#signal_type ⇒ String
Required. Signal type of the signal
Corresponds to the JSON property signalType
3703 3704 3705 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3703 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3710 3711 3712 3713 3714 3715 3716 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3710 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @resource_id = args[:resource_id] if args.key?(:resource_id) @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value) @signal_type = args[:signal_type] if args.key?(:signal_type) end |