Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

DatabaseResourceFeed is the top level proto to be used to ingest different database resource level events into Condor platform. Next ID: 13

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceFeed.



3811
3812
3813
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupdr_metadataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrMetadata

BackupDRMetadata contains information about the backup and disaster recovery metadata of a database resource. Corresponds to the JSON property backupdrMetadata



3750
3751
3752
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3750

def 
  @backupdr_metadata
end

#config_based_signal_dataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainConfigBasedSignalData

Config based signal data. This is used to send signals to Condor which are based on the DB level configurations. These will be used to send signals for self managed databases. Corresponds to the JSON property configBasedSignalData



3757
3758
3759
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3757

def config_based_signal_data
  @config_based_signal_data
end

#database_resource_signal_dataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData

Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10 Corresponds to the JSON property databaseResourceSignalData



3764
3765
3766
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3764

def database_resource_signal_data
  @database_resource_signal_data
end

#feed_timestampString

Required. Timestamp when feed is generated. Corresponds to the JSON property feedTimestamp

Returns:

  • (String)


3769
3770
3771
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3769

def feed_timestamp
  @feed_timestamp
end

#feed_typeString

Required. Type feed to be ingested into condor Corresponds to the JSON property feedType

Returns:

  • (String)


3774
3775
3776
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3774

def feed_type
  @feed_type
end

#observability_metric_dataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainObservabilityMetricData

Corresponds to the JSON property observabilityMetricData



3779
3780
3781
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3779

def observability_metric_data
  @observability_metric_data
end

#recommendation_signal_dataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceRecommendationSignalData

Common model for database resource recommendation signal data. Corresponds to the JSON property recommendationSignalData



3784
3785
3786
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3784

def recommendation_signal_data
  @recommendation_signal_data
end

#resource_health_signal_dataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData

Common model for database resource health signal data. Corresponds to the JSON property resourceHealthSignalData



3789
3790
3791
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3789

def resource_health_signal_data
  @resource_health_signal_data
end

#resource_idGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property resourceId



3794
3795
3796
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3794

def resource_id
  @resource_id
end

#resource_metadataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Common model for database resource instance metadata. Next ID: 32 Corresponds to the JSON property resourceMetadata



3799
3800
3801
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3799

def 
  @resource_metadata
end

#skip_ingestionBoolean Also known as: skip_ingestion?

Optional. If true, the feed won't be ingested by DB Center. This indicates that the feed is intentionally skipped. For example, BackupDR feeds are only needed for resources integrated with DB Center (e.g., CloudSQL, AlloyDB). Feeds for non-integrated resources (e.g., Compute Engine, Persistent Disk) can be skipped. Corresponds to the JSON property skipIngestion

Returns:

  • (Boolean)


3808
3809
3810
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3808

def skip_ingestion
  @skip_ingestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3816

def update!(**args)
  @backupdr_metadata = args[:backupdr_metadata] if args.key?(:backupdr_metadata)
  @config_based_signal_data = args[:config_based_signal_data] if args.key?(:config_based_signal_data)
  @database_resource_signal_data = args[:database_resource_signal_data] if args.key?(:database_resource_signal_data)
  @feed_timestamp = args[:feed_timestamp] if args.key?(:feed_timestamp)
  @feed_type = args[:feed_type] if args.key?(:feed_type)
  @observability_metric_data = args[:observability_metric_data] if args.key?(:observability_metric_data)
  @recommendation_signal_data = args[:recommendation_signal_data] if args.key?(:recommendation_signal_data)
  @resource_health_signal_data = args[:resource_health_signal_data] if args.key?(:resource_health_signal_data)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_metadata = args[:resource_metadata] if args.key?(:resource_metadata)
  @skip_ingestion = args[:skip_ingestion] if args.key?(:skip_ingestion)
end