Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Common model for database resource health signal data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceHealthSignalData.



3918
3919
3920
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_metadataHash<String,Object>

Any other additional metadata Corresponds to the JSON property additionalMetadata

Returns:

  • (Hash<String,Object>)


3832
3833
3834
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3832

def 
  @additional_metadata
end

#complianceArray<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainCompliance>

Industry standards associated with this signal; if this signal is an issue, that could be a violation of the associated industry standard(s). For example, AUTO_BACKUP_DISABLED signal is associated with CIS GCP 1.1, CIS GCP 1.2, CIS GCP 1.3, NIST 800-53 and ISO-27001 compliance standards. If a database resource does not have automated backup enable, it will violate these following industry standards. Corresponds to the JSON property compliance



3842
3843
3844
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3842

def compliance
  @compliance
end

#descriptionString

Description associated with signal Corresponds to the JSON property description

Returns:

  • (String)


3847
3848
3849
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3847

def description
  @description
end

#event_timeString

Required. The last time at which the event described by this signal took place Corresponds to the JSON property eventTime

Returns:

  • (String)


3852
3853
3854
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3852

def event_time
  @event_time
end

#external_uriString

The external-uri of the signal, using which more information about this signal can be obtained. In GCP, this will take user to SCC page to get more details about signals. Corresponds to the JSON property externalUri

Returns:

  • (String)


3859
3860
3861
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3859

def external_uri
  @external_uri
end

#locationString

This is used to identify the location of the resource. Example: "us-central1" Corresponds to the JSON property location

Returns:

  • (String)


3864
3865
3866
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3864

def location
  @location
end

#nameString

Required. The name of the signal, ex: PUBLIC_SQL_INSTANCE, SQL_LOG_ERROR_VERBOSITY etc. Corresponds to the JSON property name

Returns:

  • (String)


3870
3871
3872
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3870

def name
  @name
end

#providerString

Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged Corresponds to the JSON property provider

Returns:

  • (String)


3875
3876
3877
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3875

def provider
  @provider
end

#resource_containerString

Closest parent container of this resource. In GCP, 'container' refers to a Cloud Resource Manager project. It must be resource name of a Cloud Resource Manager project with the format of "provider//", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


3883
3884
3885
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3883

def resource_container
  @resource_container
end

#resource_nameString

Required. Database resource name associated with the signal. Resource name to follow CAIS resource_name format as noted here go/condor-common-datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


3889
3890
3891
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3889

def resource_name
  @resource_name
end

#signal_classString

Required. The class of the signal, such as if it's a THREAT or VULNERABILITY. Corresponds to the JSON property signalClass

Returns:

  • (String)


3894
3895
3896
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3894

def signal_class
  @signal_class
end

#signal_idString

Required. Unique identifier for the signal. This is an unique id which would be mainatined by partner to identify a signal. Corresponds to the JSON property signalId

Returns:

  • (String)


3900
3901
3902
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3900

def signal_id
  @signal_id
end

#signal_severityString

The severity of the signal, such as if it's a HIGH or LOW severity. Corresponds to the JSON property signalSeverity

Returns:

  • (String)


3905
3906
3907
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3905

def signal_severity
  @signal_severity
end

#signal_typeString

Required. Type of signal, for example, AVAILABLE_IN_MULTIPLE_ZONES, LOGGING_MOST_ERRORS, etc. Corresponds to the JSON property signalType

Returns:

  • (String)


3911
3912
3913
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3911

def signal_type
  @signal_type
end

#stateString

Corresponds to the JSON property state

Returns:

  • (String)


3916
3917
3918
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3916

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3923
3924
3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3923

def update!(**args)
  @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata)
  @compliance = args[:compliance] if args.key?(:compliance)
  @description = args[:description] if args.key?(:description)
  @event_time = args[:event_time] if args.key?(:event_time)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @signal_class = args[:signal_class] if args.key?(:signal_class)
  @signal_id = args[:signal_id] if args.key?(:signal_id)
  @signal_severity = args[:signal_severity] if args.key?(:signal_severity)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
  @state = args[:state] if args.key?(:state)
end