Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

DatabaseResourceId will serve as primary key for any resource ingestion event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceId.



3975
3976
3977
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#providerString

Required. Cloud provider name. Ex: GCP/AWS/Azure/OnPrem/SelfManaged Corresponds to the JSON property provider

Returns:

  • (String)


3949
3950
3951
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3949

def provider
  @provider
end

#provider_descriptionString

Optional. Needs to be used only when the provider is PROVIDER_OTHER. Corresponds to the JSON property providerDescription

Returns:

  • (String)


3954
3955
3956
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3954

def provider_description
  @provider_description
end

#resource_typeString

Required. The type of resource this ID is identifying. Ex go/keep-sorted start alloydb.googleapis.com/Cluster, alloydb.googleapis.com/Instance, bigtableadmin. googleapis.com/Cluster, bigtableadmin.googleapis.com/Instance compute. googleapis.com/Instance firestore.googleapis.com/Database, redis.googleapis. com/Instance, redis.googleapis.com/Cluster, oracledatabase.googleapis.com/ CloudExadataInfrastructure oracledatabase.googleapis.com/CloudVmCluster oracledatabase.googleapis.com/AutonomousDatabase spanner.googleapis.com/ Instance, spanner.googleapis.com/Database, sqladmin.googleapis.com/Instance, go/keep-sorted end REQUIRED Please refer go/condor-common-datamodel Corresponds to the JSON property resourceType

Returns:

  • (String)


3967
3968
3969
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3967

def resource_type
  @resource_type
end

#unique_idString

Required. A service-local token that distinguishes this resource from other resources within the same service. Corresponds to the JSON property uniqueId

Returns:

  • (String)


3973
3974
3975
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3973

def unique_id
  @unique_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3980
3981
3982
3983
3984
3985
# File 'lib/google/apis/alloydb_v1/classes.rb', line 3980

def update!(**args)
  @provider = args[:provider] if args.key?(:provider)
  @provider_description = args[:provider_description] if args.key?(:provider_description)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
end