Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Common model for database resource instance metadata. Next ID: 35
Instance Attribute Summary collapse
-
#additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata whichd does not support proto format.
-
#availability_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration
Configuration for availability of database instance Corresponds to the JSON property
availabilityConfiguration. -
#backup_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
-
#backupdr_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of database resource.
-
#creation_time ⇒ String
The creation time of the resource, i.e.
-
#current_state ⇒ String
Current state of the instance.
-
#custom_metadata ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainCustomMetadataData
Any custom metadata associated with the resource.
-
#edition ⇒ String
Optional.
-
#entitlements ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainEntitlement>
Entitlements associated with the resource Corresponds to the JSON property
entitlements. -
#expected_state ⇒ String
The state that the instance is expected to be in.
-
#gcbdr_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainGcbdrConfiguration
GCBDR Configuration for the resource.
-
#id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#instance_type ⇒ String
The type of the instance.
-
#internal_additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata which support proto format.
-
#ip_address ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainIpAddress
Used to send IP address information for a database resource.
-
#is_deletion_protection_enabled ⇒ Boolean
(also: #is_deletion_protection_enabled?)
Optional.
-
#location ⇒ String
The resource location.
-
#machine_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainMachineConfiguration
MachineConfiguration describes the configuration of a machine specific to Database Resource.
-
#maintenance_info ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
-
#modes ⇒ Array<String>
Optional.
-
#primary_resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#primary_resource_location ⇒ String
Primary resource location.
-
#product ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct
Product specification for Condor resources.
-
#resource_container ⇒ String
Closest parent Cloud Resource Manager container of this resource.
-
#resource_flags ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceFlags>
Optional.
-
#resource_name ⇒ String
Required.
-
#suspension_reason ⇒ String
Optional.
-
#tags_set ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainTags
Message type for storing tags.
-
#updation_time ⇒ String
The time at which the resource was updated and recorded at partner service.
-
#user_label_set ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainUserLabels
Message type for storing user labels.
-
#zone ⇒ String
The resource zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata
Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata.
4193 4194 4195 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata whichd does not support proto format.
Corresponds to the JSON property additionalMetadata
4014 4015 4016 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4014 def @additional_metadata end |
#availability_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration
Configuration for availability of database instance
Corresponds to the JSON property availabilityConfiguration
4019 4020 4021 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4019 def availability_configuration @availability_configuration end |
#backup_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
4024 4025 4026 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4024 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
Corresponds to the JSON property backupRun
4029 4030 4031 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4029 def backup_run @backup_run end |
#backupdr_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration
BackupDRConfiguration to capture the backup and disaster recovery details of
database resource.
Corresponds to the JSON property backupdrConfiguration
4035 4036 4037 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4035 def backupdr_configuration @backupdr_configuration end |
#creation_time ⇒ String
The creation time of the resource, i.e. the time when resource is created and
recorded in partner service.
Corresponds to the JSON property creationTime
4041 4042 4043 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4041 def creation_time @creation_time end |
#current_state ⇒ String
Current state of the instance.
Corresponds to the JSON property currentState
4046 4047 4048 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4046 def current_state @current_state end |
#custom_metadata ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainCustomMetadataData
Any custom metadata associated with the resource. e.g. A spanner instance can
have multiple databases with its own unique metadata. Information for these
individual databases can be captured in custom metadata data
Corresponds to the JSON property customMetadata
4053 4054 4055 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4053 def @custom_metadata end |
#edition ⇒ String
Optional. Edition represents whether the instance is ENTERPRISE or
ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to
identify the edition of the instance.
Corresponds to the JSON property edition
4060 4061 4062 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4060 def edition @edition end |
#entitlements ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainEntitlement>
Entitlements associated with the resource
Corresponds to the JSON property entitlements
4065 4066 4067 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4065 def entitlements @entitlements end |
#expected_state ⇒ String
The state that the instance is expected to be in. For example, an instance
state can transition to UNHEALTHY due to wrong patch update, while the
expected state will remain at the HEALTHY.
Corresponds to the JSON property expectedState
4072 4073 4074 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4072 def expected_state @expected_state end |
#gcbdr_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainGcbdrConfiguration
GCBDR Configuration for the resource.
Corresponds to the JSON property gcbdrConfiguration
4077 4078 4079 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4077 def gcbdr_configuration @gcbdr_configuration end |
#id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property id
4082 4083 4084 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4082 def id @id end |
#instance_type ⇒ String
The type of the instance. Specified at creation time.
Corresponds to the JSON property instanceType
4087 4088 4089 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4087 def instance_type @instance_type end |
#internal_additional_metadata ⇒ Hash<String,Object>
Field to ingest additional metadata which support proto format.
Corresponds to the JSON property internalAdditionalMetadata
4092 4093 4094 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4092 def @internal_additional_metadata end |
#ip_address ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainIpAddress
Used to send IP address information for a database resource.
Corresponds to the JSON property ipAddress
4097 4098 4099 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4097 def ip_address @ip_address end |
#is_deletion_protection_enabled ⇒ Boolean Also known as: is_deletion_protection_enabled?
Optional. Whether deletion protection is enabled for this resource.
Corresponds to the JSON property isDeletionProtectionEnabled
4102 4103 4104 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4102 def is_deletion_protection_enabled @is_deletion_protection_enabled end |
#location ⇒ String
The resource location. REQUIRED
Corresponds to the JSON property location
4108 4109 4110 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4108 def location @location end |
#machine_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainMachineConfiguration
MachineConfiguration describes the configuration of a machine specific to
Database Resource.
Corresponds to the JSON property machineConfiguration
4114 4115 4116 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4114 def machine_configuration @machine_configuration end |
#maintenance_info ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
Corresponds to the JSON property maintenanceInfo
4119 4120 4121 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4119 def maintenance_info @maintenance_info end |
#modes ⇒ Array<String>
Optional. The modes of the database resource.
Corresponds to the JSON property modes
4124 4125 4126 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4124 def modes @modes end |
#primary_resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property primaryResourceId
4129 4130 4131 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4129 def primary_resource_id @primary_resource_id end |
#primary_resource_location ⇒ String
Primary resource location. REQUIRED if the immediate parent exists when first
time resource is getting ingested, otherwise optional.
Corresponds to the JSON property primaryResourceLocation
4135 4136 4137 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4135 def primary_resource_location @primary_resource_location end |
#product ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct
Product specification for Condor resources.
Corresponds to the JSON property product
4140 4141 4142 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4140 def product @product end |
#resource_container ⇒ String
Closest parent Cloud Resource Manager container of this resource. It must be
resource name of a Cloud Resource Manager project with the format of "/", such
as "projects/123". For GCP provided resources, number should be project number.
Corresponds to the JSON property resourceContainer
4147 4148 4149 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4147 def resource_container @resource_container end |
#resource_flags ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceFlags>
Optional. List of resource flags for the database resource.
Corresponds to the JSON property resourceFlags
4152 4153 4154 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4152 def resource_flags @resource_flags end |
#resource_name ⇒ String
Required. Different from DatabaseResourceId.unique_id, a resource name can be
reused over time. That is, after a resource named "ABC" is deleted, the name "
ABC" can be used to to create a new resource within the same source. Resource
name to follow CAIS resource_name format as noted here go/condor-common-
datamodel
Corresponds to the JSON property resourceName
4161 4162 4163 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4161 def resource_name @resource_name end |
#suspension_reason ⇒ String
Optional. Suspension reason for the resource.
Corresponds to the JSON property suspensionReason
4166 4167 4168 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4166 def suspension_reason @suspension_reason end |
#tags_set ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainTags
Message type for storing tags. Tags provide a way to create annotations for
resources, and in some cases conditionally allow or deny policies based on
whether a resource has a specific tag.
Corresponds to the JSON property tagsSet
4173 4174 4175 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4173 def @tags_set end |
#updation_time ⇒ String
The time at which the resource was updated and recorded at partner service.
Corresponds to the JSON property updationTime
4178 4179 4180 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4178 def updation_time @updation_time end |
#user_label_set ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainUserLabels
Message type for storing user labels. User labels are used to tag App Engine
resources, allowing users to search for resources matching a set of labels and
to aggregate usage data by labels.
Corresponds to the JSON property userLabelSet
4185 4186 4187 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4185 def user_label_set @user_label_set end |
#zone ⇒ String
The resource zone. This is only applicable for zonal resources and will be
empty for regional and multi-regional resources.
Corresponds to the JSON property zone
4191 4192 4193 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4191 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4198 def update!(**args) @additional_metadata = args[:additional_metadata] if args.key?(:additional_metadata) @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration) @creation_time = args[:creation_time] if args.key?(:creation_time) @current_state = args[:current_state] if args.key?(:current_state) @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata) @edition = args[:edition] if args.key?(:edition) @entitlements = args[:entitlements] if args.key?(:entitlements) @expected_state = args[:expected_state] if args.key?(:expected_state) @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration) @id = args[:id] if args.key?(:id) @instance_type = args[:instance_type] if args.key?(:instance_type) @internal_additional_metadata = args[:internal_additional_metadata] if args.key?(:internal_additional_metadata) @ip_address = args[:ip_address] if args.key?(:ip_address) @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled) @location = args[:location] if args.key?(:location) @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration) @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info) @modes = args[:modes] if args.key?(:modes) @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id) @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location) @product = args[:product] if args.key?(:product) @resource_container = args[:resource_container] if args.key?(:resource_container) @resource_flags = args[:resource_flags] if args.key?(:resource_flags) @resource_name = args[:resource_name] if args.key?(:resource_name) @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason) @tags_set = args[:tags_set] if args.key?(:tags_set) @updation_time = args[:updation_time] if args.key?(:updation_time) @user_label_set = args[:user_label_set] if args.key?(:user_label_set) @zone = args[:zone] if args.key?(:zone) end |