Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

Common model for database resource instance metadata. Next ID: 32

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata

Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceMetadata.



4165
4166
4167
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainAvailabilityConfiguration

Configuration for availability of database instance Corresponds to the JSON property availabilityConfiguration



4001
4002
4003
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4001

def availability_configuration
  @availability_configuration
end

#backup_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration

Configuration for automatic backups Corresponds to the JSON property backupConfiguration



4006
4007
4008
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4006

def backup_configuration
  @backup_configuration
end

#backup_runGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun

A backup run. Corresponds to the JSON property backupRun



4011
4012
4013
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4011

def backup_run
  @backup_run
end

#backupdr_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupDrConfiguration

BackupDRConfiguration to capture the backup and disaster recovery details of database resource. Corresponds to the JSON property backupdrConfiguration



4017
4018
4019
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4017

def backupdr_configuration
  @backupdr_configuration
end

#creation_timeString

The creation time of the resource, i.e. the time when resource is created and recorded in partner service. Corresponds to the JSON property creationTime

Returns:

  • (String)


4023
4024
4025
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4023

def creation_time
  @creation_time
end

#current_stateString

Current state of the instance. Corresponds to the JSON property currentState

Returns:

  • (String)


4028
4029
4030
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4028

def current_state
  @current_state
end

#custom_metadataGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainCustomMetadataData

Any custom metadata associated with the resource. e.g. A spanner instance can have multiple databases with its own unique metadata. Information for these individual databases can be captured in custom metadata data Corresponds to the JSON property customMetadata



4035
4036
4037
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4035

def 
  @custom_metadata
end

#editionString

Optional. Edition represents whether the instance is ENTERPRISE or ENTERPRISE_PLUS. This information is core to Cloud SQL only and is used to identify the edition of the instance. Corresponds to the JSON property edition

Returns:

  • (String)


4042
4043
4044
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4042

def edition
  @edition
end

#entitlementsArray<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainEntitlement>

Entitlements associated with the resource Corresponds to the JSON property entitlements



4047
4048
4049
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4047

def entitlements
  @entitlements
end

#expected_stateString

The state that the instance is expected to be in. For example, an instance state can transition to UNHEALTHY due to wrong patch update, while the expected state will remain at the HEALTHY. Corresponds to the JSON property expectedState

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4054

def expected_state
  @expected_state
end

#gcbdr_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainGcbdrConfiguration

GCBDR Configuration for the resource. Corresponds to the JSON property gcbdrConfiguration



4059
4060
4061
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4059

def gcbdr_configuration
  @gcbdr_configuration
end

#idGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property id



4064
4065
4066
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4064

def id
  @id
end

#instance_typeString

The type of the instance. Specified at creation time. Corresponds to the JSON property instanceType

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4069

def instance_type
  @instance_type
end

#is_deletion_protection_enabledBoolean Also known as: is_deletion_protection_enabled?

Optional. Whether deletion protection is enabled for this resource. Corresponds to the JSON property isDeletionProtectionEnabled

Returns:

  • (Boolean)


4074
4075
4076
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4074

def is_deletion_protection_enabled
  @is_deletion_protection_enabled
end

#locationString

The resource location. REQUIRED Corresponds to the JSON property location

Returns:

  • (String)


4080
4081
4082
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4080

def location
  @location
end

#machine_configurationGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainMachineConfiguration

MachineConfiguration describes the configuration of a machine specific to Database Resource. Corresponds to the JSON property machineConfiguration



4086
4087
4088
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4086

def machine_configuration
  @machine_configuration
end

#maintenance_infoGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

MaintenanceInfo to capture the maintenance details of database resource. Corresponds to the JSON property maintenanceInfo



4091
4092
4093
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4091

def maintenance_info
  @maintenance_info
end

#modesArray<String>

Optional. The modes of the database resource. Corresponds to the JSON property modes

Returns:

  • (Array<String>)


4096
4097
4098
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4096

def modes
  @modes
end

#primary_resource_idGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId

DatabaseResourceId will serve as primary key for any resource ingestion event. Corresponds to the JSON property primaryResourceId



4101
4102
4103
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4101

def primary_resource_id
  @primary_resource_id
end

#primary_resource_locationString

Primary resource location. REQUIRED if the immediate parent exists when first time resource is getting ingested, otherwise optional. Corresponds to the JSON property primaryResourceLocation

Returns:

  • (String)


4107
4108
4109
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4107

def primary_resource_location
  @primary_resource_location
end

#productGoogle::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct

Product specification for Condor resources. Corresponds to the JSON property product



4112
4113
4114
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4112

def product
  @product
end

#resource_containerString

Closest parent Cloud Resource Manager container of this resource. It must be resource name of a Cloud Resource Manager project with the format of "/", such as "projects/123". For GCP provided resources, number should be project number. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4119

def resource_container
  @resource_container
end

#resource_flagsArray<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceFlags>

Optional. List of resource flags for the database resource. Corresponds to the JSON property resourceFlags



4124
4125
4126
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4124

def resource_flags
  @resource_flags
end

#resource_nameString

Required. Different from DatabaseResourceId.unique_id, a resource name can be reused over time. That is, after a resource named "ABC" is deleted, the name " ABC" can be used to to create a new resource within the same source. Resource name to follow CAIS resource_name format as noted here go/condor-common- datamodel Corresponds to the JSON property resourceName

Returns:

  • (String)


4133
4134
4135
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4133

def resource_name
  @resource_name
end

#suspension_reasonString

Optional. Suspension reason for the resource. Corresponds to the JSON property suspensionReason

Returns:

  • (String)


4138
4139
4140
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4138

def suspension_reason
  @suspension_reason
end

#tags_setGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainTags

Message type for storing tags. Tags provide a way to create annotations for resources, and in some cases conditionally allow or deny policies based on whether a resource has a specific tag. Corresponds to the JSON property tagsSet



4145
4146
4147
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4145

def tags_set
  @tags_set
end

#updation_timeString

The time at which the resource was updated and recorded at partner service. Corresponds to the JSON property updationTime

Returns:

  • (String)


4150
4151
4152
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4150

def updation_time
  @updation_time
end

#user_label_setGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainUserLabels

Message type for storing user labels. User labels are used to tag App Engine resources, allowing users to search for resources matching a set of labels and to aggregate usage data by labels. Corresponds to the JSON property userLabelSet



4157
4158
4159
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4157

def user_label_set
  @user_label_set
end

#zoneString

The resource zone. This is only applicable for zonal resources and will be empty for regional and multi-regional resources. Corresponds to the JSON property zone

Returns:

  • (String)


4163
4164
4165
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4163

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4170
4171
4172
4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
4197
4198
4199
4200
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4170

def update!(**args)
  @availability_configuration = args[:availability_configuration] if args.key?(:availability_configuration)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @backup_run = args[:backup_run] if args.key?(:backup_run)
  @backupdr_configuration = args[:backupdr_configuration] if args.key?(:backupdr_configuration)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @current_state = args[:current_state] if args.key?(:current_state)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @edition = args[:edition] if args.key?(:edition)
  @entitlements = args[:entitlements] if args.key?(:entitlements)
  @expected_state = args[:expected_state] if args.key?(:expected_state)
  @gcbdr_configuration = args[:gcbdr_configuration] if args.key?(:gcbdr_configuration)
  @id = args[:id] if args.key?(:id)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled)
  @location = args[:location] if args.key?(:location)
  @machine_configuration = args[:machine_configuration] if args.key?(:machine_configuration)
  @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info)
  @modes = args[:modes] if args.key?(:modes)
  @primary_resource_id = args[:primary_resource_id] if args.key?(:primary_resource_id)
  @primary_resource_location = args[:primary_resource_location] if args.key?(:primary_resource_location)
  @product = args[:product] if args.key?(:product)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @resource_flags = args[:resource_flags] if args.key?(:resource_flags)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @tags_set = args[:tags_set] if args.key?(:tags_set)
  @updation_time = args[:updation_time] if args.key?(:updation_time)
  @user_label_set = args[:user_label_set] if args.key?(:user_label_set)
  @zone = args[:zone] if args.key?(:zone)
end