Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Database resource signal data. This is used to send signals to Condor which are based on the DB/Instance/Fleet level configurations. These will be used to send signals for all inventory types. Next ID: 10
Instance Attribute Summary collapse
-
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
-
#full_resource_name ⇒ String
Required.
-
#last_refresh_time ⇒ String
Required.
-
#location ⇒ String
Resource location.
-
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#signal_bool_value ⇒ Boolean
(also: #signal_bool_value?)
Deprecated: Use signal_metadata_list instead.
-
#signal_metadata_list ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainSignalMetadata>
This will support array of OneOf signal metadata information for a given signal type.
-
#signal_state ⇒ String
Required.
-
#signal_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData
Returns a new instance of StorageDatabasecenterPartnerapiV1mainDatabaseResourceSignalData.
4323 4324 4325 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
Corresponds to the JSON property backupRun
4279 4280 4281 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4279 def backup_run @backup_run end |
#full_resource_name ⇒ String
Required. Full Resource name of the source resource.
Corresponds to the JSON property fullResourceName
4284 4285 4286 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4284 def full_resource_name @full_resource_name end |
#last_refresh_time ⇒ String
Required. Last time signal was refreshed
Corresponds to the JSON property lastRefreshTime
4289 4290 4291 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4289 def last_refresh_time @last_refresh_time end |
#location ⇒ String
Resource location.
Corresponds to the JSON property location
4294 4295 4296 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4294 def location @location end |
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
4299 4300 4301 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4299 def resource_id @resource_id end |
#signal_bool_value ⇒ Boolean Also known as: signal_bool_value?
Deprecated: Use signal_metadata_list instead.
Corresponds to the JSON property signalBoolValue
4304 4305 4306 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4304 def signal_bool_value @signal_bool_value end |
#signal_metadata_list ⇒ Array<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainSignalMetadata>
This will support array of OneOf signal metadata information for a given
signal type.
Corresponds to the JSON property signalMetadataList
4311 4312 4313 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4311 def @signal_metadata_list end |
#signal_state ⇒ String
Required. Output only. Signal state of the signal
Corresponds to the JSON property signalState
4316 4317 4318 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4316 def signal_state @signal_state end |
#signal_type ⇒ String
Required. Signal type of the signal
Corresponds to the JSON property signalType
4321 4322 4323 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4321 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4328 def update!(**args) @backup_run = args[:backup_run] if args.key?(:backup_run) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @last_refresh_time = args[:last_refresh_time] if args.key?(:last_refresh_time) @location = args[:location] if args.key?(:location) @resource_id = args[:resource_id] if args.key?(:resource_id) @signal_bool_value = args[:signal_bool_value] if args.key?(:signal_bool_value) @signal_metadata_list = args[:signal_metadata_list] if args.key?(:signal_metadata_list) @signal_state = args[:signal_state] if args.key?(:signal_state) @signal_type = args[:signal_type] if args.key?(:signal_type) end |