Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Metadata for individual internal resources in an instance. e.g. spanner instance can have multiple databases with unique configuration settings. Similarly bigtable can have multiple clusters within same bigtable instance.
Instance Attribute Summary collapse
-
#backup_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups Corresponds to the JSON property
backupConfiguration. -
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
-
#is_deletion_protection_enabled ⇒ Boolean
(also: #is_deletion_protection_enabled?)
Whether deletion protection is enabled for this internal resource.
-
#product ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct
Product specification for Condor resources.
-
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
-
#resource_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata
constructor
A new instance of StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata
Returns a new instance of StorageDatabasecenterPartnerapiV1mainInternalResourceMetadata.
4425 4426 4427 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_configuration ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupConfiguration
Configuration for automatic backups
Corresponds to the JSON property backupConfiguration
4396 4397 4398 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4396 def backup_configuration @backup_configuration end |
#backup_run ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainBackupRun
A backup run.
Corresponds to the JSON property backupRun
4401 4402 4403 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4401 def backup_run @backup_run end |
#is_deletion_protection_enabled ⇒ Boolean Also known as: is_deletion_protection_enabled?
Whether deletion protection is enabled for this internal resource.
Corresponds to the JSON property isDeletionProtectionEnabled
4406 4407 4408 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4406 def is_deletion_protection_enabled @is_deletion_protection_enabled end |
#product ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterProtoCommonProduct
Product specification for Condor resources.
Corresponds to the JSON property product
4412 4413 4414 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4412 def product @product end |
#resource_id ⇒ Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainDatabaseResourceId
DatabaseResourceId will serve as primary key for any resource ingestion event.
Corresponds to the JSON property resourceId
4417 4418 4419 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4417 def resource_id @resource_id end |
#resource_name ⇒ String
Required. internal resource name for spanner this will be database name e.g."
spanner.googleapis.com/projects/123/abc/instances/inst1/databases/db1"
Corresponds to the JSON property resourceName
4423 4424 4425 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4423 def resource_name @resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4430 4431 4432 4433 4434 4435 4436 4437 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4430 def update!(**args) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @backup_run = args[:backup_run] if args.key?(:backup_run) @is_deletion_protection_enabled = args[:is_deletion_protection_enabled] if args.key?(:is_deletion_protection_enabled) @product = args[:product] if args.key?(:product) @resource_id = args[:resource_id] if args.key?(:resource_id) @resource_name = args[:resource_name] if args.key?(:resource_name) end |