Class: Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb

Overview

MaintenanceInfo to capture the maintenance details of database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo

Returns a new instance of StorageDatabasecenterPartnerapiV1mainResourceMaintenanceInfo.



4749
4750
4751
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_version_release_dateGoogle::Apis::AlloydbV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property currentVersionReleaseDate



4710
4711
4712
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4710

def current_version_release_date
  @current_version_release_date
end

#deny_maintenance_schedulesArray<Google::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceDenySchedule>

Optional. List of Deny maintenance period for the database resource. Corresponds to the JSON property denyMaintenanceSchedules



4715
4716
4717
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4715

def deny_maintenance_schedules
  @deny_maintenance_schedules
end

#is_instance_stoppedBoolean Also known as: is_instance_stopped?

Optional. Whether the instance is in stopped state. This information is temporarily being captured in maintenanceInfo, till STOPPED state is supported by DB Center. Corresponds to the JSON property isInstanceStopped

Returns:

  • (Boolean)


4722
4723
4724
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4722

def is_instance_stopped
  @is_instance_stopped
end

#maintenance_scheduleGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainResourceMaintenanceSchedule

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. This is configured by the customer. Corresponds to the JSON property maintenanceSchedule



4730
4731
4732
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4730

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_stateString

Output only. Current state of maintenance on the database resource. Corresponds to the JSON property maintenanceState

Returns:

  • (String)


4735
4736
4737
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4735

def maintenance_state
  @maintenance_state
end

#maintenance_versionString

Optional. Current Maintenance version of the database resource. Example: " MYSQL_8_0_41.R20250531.01_15" Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


4741
4742
4743
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4741

def maintenance_version
  @maintenance_version
end

#upcoming_maintenanceGoogle::Apis::AlloydbV1::StorageDatabasecenterPartnerapiV1mainUpcomingMaintenance

Upcoming maintenance for the database resource. This is generated by SLM once the upcoming maintenance schedule is published. Corresponds to the JSON property upcomingMaintenance



4747
4748
4749
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4747

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4754
4755
4756
4757
4758
4759
4760
4761
4762
# File 'lib/google/apis/alloydb_v1/classes.rb', line 4754

def update!(**args)
  @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date)
  @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules)
  @is_instance_stopped = args[:is_instance_stopped] if args.key?(:is_instance_stopped)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_state = args[:maintenance_state] if args.key?(:maintenance_state)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end