Class: Google::Apis::AlloydbV1::UpgradeClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::UpgradeClusterRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Upgrades a cluster.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeClusterRequest
constructor
A new instance of UpgradeClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeClusterRequest
Returns a new instance of UpgradeClusterRequest.
5265 5266 5267 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. The current etag of the Cluster. If an etag is provided and does not
match the current etag of the Cluster, upgrade will be blocked and an ABORTED
error will be returned.
Corresponds to the JSON property etag
5236 5237 5238 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5236 def etag @etag end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server ignores the
request if it has already been completed. The server guarantees that for at
least 60 minutes since the first request. For example, consider a situation
where you make an initial request and the request times out. If you make the
request again with the same request ID, the server can check if the original
operation with the same request ID was received, and if so, ignores the second
request. This prevents clients from accidentally creating duplicate
commitments. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
5250 5251 5252 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5250 def request_id @request_id end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, performs request validation, for example, permission checks
and any other type of validation, but does not actually execute the create
request.
Corresponds to the JSON property validateOnly
5257 5258 5259 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5257 def validate_only @validate_only end |
#version ⇒ String
Required. The version the cluster is going to be upgraded to.
Corresponds to the JSON property version
5263 5264 5265 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5263 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5270 5271 5272 5273 5274 5275 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5270 def update!(**args) @etag = args[:etag] if args.key?(:etag) @request_id = args[:request_id] if args.key?(:request_id) @validate_only = args[:validate_only] if args.key?(:validate_only) @version = args[:version] if args.key?(:version) end |