Class: Google::Apis::AlloydbV1::User
- Inherits:
-
Object
- Object
- Google::Apis::AlloydbV1::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/alloydb_v1/classes.rb,
lib/google/apis/alloydb_v1/representations.rb,
lib/google/apis/alloydb_v1/representations.rb
Overview
Message describing User object.
Instance Attribute Summary collapse
-
#database_roles ⇒ Array<String>
Optional.
-
#keep_extra_roles ⇒ Boolean
(also: #keep_extra_roles?)
Input only.
-
#name ⇒ String
Output only.
-
#password ⇒ String
Input only.
-
#user_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
5336 5337 5338 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_roles ⇒ Array<String>
Optional. List of database roles this user has. The database role strings are
subject to the PostgreSQL naming conventions.
Corresponds to the JSON property databaseRoles
5311 5312 5313 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5311 def database_roles @database_roles end |
#keep_extra_roles ⇒ Boolean Also known as: keep_extra_roles?
Input only. If the user already exists and it has additional roles, keep them
granted.
Corresponds to the JSON property keepExtraRoles
5317 5318 5319 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5317 def keep_extra_roles @keep_extra_roles end |
#name ⇒ String
Output only. Name of the resource in the form of projects/project/locations/
location/cluster/cluster/users/user.
Corresponds to the JSON property name
5324 5325 5326 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5324 def name @name end |
#password ⇒ String
Input only. Password for the user.
Corresponds to the JSON property password
5329 5330 5331 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5329 def password @password end |
#user_type ⇒ String
Optional. Type of this user.
Corresponds to the JSON property userType
5334 5335 5336 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5334 def user_type @user_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5341 5342 5343 5344 5345 5346 5347 |
# File 'lib/google/apis/alloydb_v1/classes.rb', line 5341 def update!(**args) @database_roles = args[:database_roles] if args.key?(:database_roles) @keep_extra_roles = args[:keep_extra_roles] if args.key?(:keep_extra_roles) @name = args[:name] if args.key?(:name) @password = args[:password] if args.key?(:password) @user_type = args[:user_type] if args.key?(:user_type) end |